/* Automatically @generated by tree-sitter v0.25.8 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 597
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 143
#define ALIAS_COUNT 0
#define TOKEN_COUNT 68
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 7
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 6
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_BANG = 1,
  anon_sym_LF = 2,
  anon_sym_end = 3,
  anon_sym_EQ = 4,
  anon_sym_SEMI = 5,
  anon_sym_COMMA = 6,
  anon_sym_LBRACK = 7,
  anon_sym_RBRACK = 8,
  aux_sym_compound_variable_declaration_token1 = 9,
  aux_sym_compound_boolean_token1 = 10,
  aux_sym_compound_boolean_token2 = 11,
  aux_sym_compound_step_block_token1 = 12,
  aux_sym_compound_step_block_token2 = 13,
  aux_sym_compound_step_block_token3 = 14,
  aux_sym_compound_step_block_token4 = 15,
  anon_sym_PLUS = 16,
  anon_sym_DASH = 17,
  anon_sym_STAR = 18,
  anon_sym_SLASH = 19,
  anon_sym_LPAREN = 20,
  anon_sym_RPAREN = 21,
  aux_sym_compound_for_loop_token1 = 22,
  aux_sym_compound_for_loop_token2 = 23,
  aux_sym_compound_for_loop_token3 = 24,
  aux_sym_compound_for_loop_token4 = 25,
  aux_sym_compound_for_loop_token5 = 26,
  aux_sym_compound_if_block_token1 = 27,
  aux_sym_compound_if_block_token2 = 28,
  aux_sym_compound_if_block_token3 = 29,
  aux_sym_compound_if_block_token4 = 30,
  aux_sym_compound_array_assignment_token1 = 31,
  aux_sym_compound_condition_token1 = 32,
  aux_sym_compound_condition_token2 = 33,
  anon_sym_LT = 34,
  anon_sym_GT = 35,
  anon_sym_LT_EQ = 36,
  anon_sym_GT_EQ = 37,
  anon_sym_EQ_EQ = 38,
  anon_sym_BANG_EQ = 39,
  anon_sym_PERCENT = 40,
  aux_sym_compound_script_token1 = 41,
  aux_sym_compound_script_token2 = 42,
  aux_sym_compound_script_token3 = 43,
  anon_sym_AMP_LBRACE = 44,
  anon_sym_RBRACE = 45,
  anon_sym_xyz = 46,
  anon_sym_int = 47,
  anon_sym_gzmt = 48,
  anon_sym_xyzfile = 49,
  anon_sym_gzmtfile = 50,
  anon_sym_LBRACE = 51,
  anon_sym_A = 52,
  anon_sym_B = 53,
  anon_sym_D = 54,
  anon_sym_T = 55,
  anon_sym_C = 56,
  anon_sym_S = 57,
  anon_sym_F = 58,
  sym_comment = 59,
  sym_element = 60,
  sym_word = 61,
  sym_string = 62,
  sym_quoted_string = 63,
  sym_float = 64,
  sym_integer = 65,
  sym_file = 66,
  aux_sym_arg_token1 = 67,
  sym_source_file = 68,
  sym_simple_line = 69,
  sym__input = 70,
  sym_input_line = 71,
  sym_input_block = 72,
  sym_input_body = 73,
  sym_subblock = 74,
  sym_kv_pair = 75,
  sym_variable_def = 76,
  sym_variable_name = 77,
  sym_variable_range = 78,
  sym_variable_array = 79,
  sym_compound_variable_declaration = 80,
  sym_compound_value = 81,
  sym_compound_boolean = 82,
  sym_compound_array = 83,
  sym_compound_step_block = 84,
  sym_compound_step_body = 85,
  sym_compound_assignment = 86,
  sym_compound_assignment_value = 87,
  sym_compound_expression = 88,
  sym_compound_additive_expr = 89,
  sym_compound_multiplicative_expr = 90,
  sym_compound_primary_expr = 91,
  sym_compound_array_access = 92,
  sym_compound_for_loop = 93,
  sym_compound_if_block = 94,
  sym_compound_statement = 95,
  sym_compound_array_assignment = 96,
  sym_compound_condition = 97,
  sym_compound_comparison = 98,
  sym_compound_function_call = 99,
  sym_compound_argument_list = 100,
  sym_compound_script = 101,
  sym_compound_variable_reference = 102,
  sym_compound_end = 103,
  sym_value = 104,
  sym_value_atom = 105,
  sym_input_key = 106,
  sym_input_title = 107,
  sym__geom = 108,
  sym_geom_line = 109,
  sym_geom_block = 110,
  sym_geom_line_types = 111,
  sym_int_line = 112,
  sym_zmat_line1 = 113,
  sym_zmat_line2 = 114,
  sym_zmat_line3 = 115,
  sym_zmat_line4 = 116,
  sym_xyz_line = 117,
  sym_coord_value = 118,
  sym_variable_ref = 119,
  sym_array = 120,
  sym_brace_block = 121,
  sym_brace_content = 122,
  sym_brace_value = 123,
  sym_constraint_content = 124,
  sym_raw_content = 125,
  sym_arg = 126,
  aux_sym_source_file_repeat1 = 127,
  aux_sym_simple_line_repeat1 = 128,
  aux_sym_input_body_repeat1 = 129,
  aux_sym_subblock_repeat1 = 130,
  aux_sym_subblock_repeat2 = 131,
  aux_sym_subblock_repeat3 = 132,
  aux_sym_variable_array_repeat1 = 133,
  aux_sym_compound_variable_declaration_repeat1 = 134,
  aux_sym_compound_array_repeat1 = 135,
  aux_sym_compound_step_body_repeat1 = 136,
  aux_sym_compound_for_loop_repeat1 = 137,
  aux_sym_compound_argument_list_repeat1 = 138,
  aux_sym_compound_script_repeat1 = 139,
  aux_sym_value_repeat1 = 140,
  aux_sym_brace_content_repeat1 = 141,
  aux_sym_constraint_content_repeat1 = 142,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_BANG] = "!",
  [anon_sym_LF] = "\n",
  [anon_sym_end] = "end",
  [anon_sym_EQ] = "=",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [aux_sym_compound_variable_declaration_token1] = "compound_variable_declaration_token1",
  [aux_sym_compound_boolean_token1] = "compound_boolean_token1",
  [aux_sym_compound_boolean_token2] = "compound_boolean_token2",
  [aux_sym_compound_step_block_token1] = "compound_step_block_token1",
  [aux_sym_compound_step_block_token2] = "compound_step_block_token2",
  [aux_sym_compound_step_block_token3] = "compound_step_block_token3",
  [aux_sym_compound_step_block_token4] = "compound_step_block_token4",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [aux_sym_compound_for_loop_token1] = "compound_for_loop_token1",
  [aux_sym_compound_for_loop_token2] = "compound_for_loop_token2",
  [aux_sym_compound_for_loop_token3] = "compound_for_loop_token3",
  [aux_sym_compound_for_loop_token4] = "compound_for_loop_token4",
  [aux_sym_compound_for_loop_token5] = "compound_for_loop_token5",
  [aux_sym_compound_if_block_token1] = "compound_if_block_token1",
  [aux_sym_compound_if_block_token2] = "compound_if_block_token2",
  [aux_sym_compound_if_block_token3] = "compound_if_block_token3",
  [aux_sym_compound_if_block_token4] = "compound_if_block_token4",
  [aux_sym_compound_array_assignment_token1] = "compound_array_assignment_token1",
  [aux_sym_compound_condition_token1] = "compound_condition_token1",
  [aux_sym_compound_condition_token2] = "compound_condition_token2",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_PERCENT] = "%",
  [aux_sym_compound_script_token1] = "compound_script_token1",
  [aux_sym_compound_script_token2] = "compound_script_token2",
  [aux_sym_compound_script_token3] = "compound_script_token3",
  [anon_sym_AMP_LBRACE] = "&{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_xyz] = "xyz",
  [anon_sym_int] = "int",
  [anon_sym_gzmt] = "gzmt",
  [anon_sym_xyzfile] = "xyzfile",
  [anon_sym_gzmtfile] = "gzmtfile",
  [anon_sym_LBRACE] = "{",
  [anon_sym_A] = "A",
  [anon_sym_B] = "B",
  [anon_sym_D] = "D",
  [anon_sym_T] = "T",
  [anon_sym_C] = "C",
  [anon_sym_S] = "S",
  [anon_sym_F] = "F",
  [sym_comment] = "comment",
  [sym_element] = "element",
  [sym_word] = "word",
  [sym_string] = "string",
  [sym_quoted_string] = "quoted_string",
  [sym_float] = "float",
  [sym_integer] = "integer",
  [sym_file] = "file",
  [aux_sym_arg_token1] = "arg_token1",
  [sym_source_file] = "source_file",
  [sym_simple_line] = "simple_line",
  [sym__input] = "_input",
  [sym_input_line] = "input_line",
  [sym_input_block] = "input_block",
  [sym_input_body] = "input_body",
  [sym_subblock] = "subblock",
  [sym_kv_pair] = "kv_pair",
  [sym_variable_def] = "variable_def",
  [sym_variable_name] = "variable_name",
  [sym_variable_range] = "variable_range",
  [sym_variable_array] = "variable_array",
  [sym_compound_variable_declaration] = "compound_variable_declaration",
  [sym_compound_value] = "compound_value",
  [sym_compound_boolean] = "compound_boolean",
  [sym_compound_array] = "compound_array",
  [sym_compound_step_block] = "compound_step_block",
  [sym_compound_step_body] = "compound_step_body",
  [sym_compound_assignment] = "compound_assignment",
  [sym_compound_assignment_value] = "compound_assignment_value",
  [sym_compound_expression] = "compound_expression",
  [sym_compound_additive_expr] = "compound_additive_expr",
  [sym_compound_multiplicative_expr] = "compound_multiplicative_expr",
  [sym_compound_primary_expr] = "compound_primary_expr",
  [sym_compound_array_access] = "compound_array_access",
  [sym_compound_for_loop] = "compound_for_loop",
  [sym_compound_if_block] = "compound_if_block",
  [sym_compound_statement] = "compound_statement",
  [sym_compound_array_assignment] = "compound_array_assignment",
  [sym_compound_condition] = "compound_condition",
  [sym_compound_comparison] = "compound_comparison",
  [sym_compound_function_call] = "compound_function_call",
  [sym_compound_argument_list] = "compound_argument_list",
  [sym_compound_script] = "compound_script",
  [sym_compound_variable_reference] = "compound_variable_reference",
  [sym_compound_end] = "compound_end",
  [sym_value] = "value",
  [sym_value_atom] = "value_atom",
  [sym_input_key] = "input_key",
  [sym_input_title] = "input_title",
  [sym__geom] = "_geom",
  [sym_geom_line] = "geom_line",
  [sym_geom_block] = "geom_block",
  [sym_geom_line_types] = "geom_line_types",
  [sym_int_line] = "int_line",
  [sym_zmat_line1] = "zmat_line1",
  [sym_zmat_line2] = "zmat_line2",
  [sym_zmat_line3] = "zmat_line3",
  [sym_zmat_line4] = "zmat_line4",
  [sym_xyz_line] = "xyz_line",
  [sym_coord_value] = "coord_value",
  [sym_variable_ref] = "variable_ref",
  [sym_array] = "array",
  [sym_brace_block] = "brace_block",
  [sym_brace_content] = "brace_content",
  [sym_brace_value] = "brace_value",
  [sym_constraint_content] = "constraint_content",
  [sym_raw_content] = "raw_content",
  [sym_arg] = "arg",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_simple_line_repeat1] = "simple_line_repeat1",
  [aux_sym_input_body_repeat1] = "input_body_repeat1",
  [aux_sym_subblock_repeat1] = "subblock_repeat1",
  [aux_sym_subblock_repeat2] = "subblock_repeat2",
  [aux_sym_subblock_repeat3] = "subblock_repeat3",
  [aux_sym_variable_array_repeat1] = "variable_array_repeat1",
  [aux_sym_compound_variable_declaration_repeat1] = "compound_variable_declaration_repeat1",
  [aux_sym_compound_array_repeat1] = "compound_array_repeat1",
  [aux_sym_compound_step_body_repeat1] = "compound_step_body_repeat1",
  [aux_sym_compound_for_loop_repeat1] = "compound_for_loop_repeat1",
  [aux_sym_compound_argument_list_repeat1] = "compound_argument_list_repeat1",
  [aux_sym_compound_script_repeat1] = "compound_script_repeat1",
  [aux_sym_value_repeat1] = "value_repeat1",
  [aux_sym_brace_content_repeat1] = "brace_content_repeat1",
  [aux_sym_constraint_content_repeat1] = "constraint_content_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [aux_sym_compound_variable_declaration_token1] = aux_sym_compound_variable_declaration_token1,
  [aux_sym_compound_boolean_token1] = aux_sym_compound_boolean_token1,
  [aux_sym_compound_boolean_token2] = aux_sym_compound_boolean_token2,
  [aux_sym_compound_step_block_token1] = aux_sym_compound_step_block_token1,
  [aux_sym_compound_step_block_token2] = aux_sym_compound_step_block_token2,
  [aux_sym_compound_step_block_token3] = aux_sym_compound_step_block_token3,
  [aux_sym_compound_step_block_token4] = aux_sym_compound_step_block_token4,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_compound_for_loop_token1] = aux_sym_compound_for_loop_token1,
  [aux_sym_compound_for_loop_token2] = aux_sym_compound_for_loop_token2,
  [aux_sym_compound_for_loop_token3] = aux_sym_compound_for_loop_token3,
  [aux_sym_compound_for_loop_token4] = aux_sym_compound_for_loop_token4,
  [aux_sym_compound_for_loop_token5] = aux_sym_compound_for_loop_token5,
  [aux_sym_compound_if_block_token1] = aux_sym_compound_if_block_token1,
  [aux_sym_compound_if_block_token2] = aux_sym_compound_if_block_token2,
  [aux_sym_compound_if_block_token3] = aux_sym_compound_if_block_token3,
  [aux_sym_compound_if_block_token4] = aux_sym_compound_if_block_token4,
  [aux_sym_compound_array_assignment_token1] = aux_sym_compound_array_assignment_token1,
  [aux_sym_compound_condition_token1] = aux_sym_compound_condition_token1,
  [aux_sym_compound_condition_token2] = aux_sym_compound_condition_token2,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [aux_sym_compound_script_token1] = aux_sym_compound_script_token1,
  [aux_sym_compound_script_token2] = aux_sym_compound_script_token2,
  [aux_sym_compound_script_token3] = aux_sym_compound_script_token3,
  [anon_sym_AMP_LBRACE] = anon_sym_AMP_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_xyz] = anon_sym_xyz,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_gzmt] = anon_sym_gzmt,
  [anon_sym_xyzfile] = anon_sym_xyzfile,
  [anon_sym_gzmtfile] = anon_sym_gzmtfile,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_A] = anon_sym_A,
  [anon_sym_B] = anon_sym_B,
  [anon_sym_D] = anon_sym_D,
  [anon_sym_T] = anon_sym_T,
  [anon_sym_C] = anon_sym_C,
  [anon_sym_S] = anon_sym_S,
  [anon_sym_F] = anon_sym_F,
  [sym_comment] = sym_comment,
  [sym_element] = sym_element,
  [sym_word] = sym_word,
  [sym_string] = sym_string,
  [sym_quoted_string] = sym_quoted_string,
  [sym_float] = sym_float,
  [sym_integer] = sym_integer,
  [sym_file] = sym_file,
  [aux_sym_arg_token1] = aux_sym_arg_token1,
  [sym_source_file] = sym_source_file,
  [sym_simple_line] = sym_simple_line,
  [sym__input] = sym__input,
  [sym_input_line] = sym_input_line,
  [sym_input_block] = sym_input_block,
  [sym_input_body] = sym_input_body,
  [sym_subblock] = sym_subblock,
  [sym_kv_pair] = sym_kv_pair,
  [sym_variable_def] = sym_variable_def,
  [sym_variable_name] = sym_variable_name,
  [sym_variable_range] = sym_variable_range,
  [sym_variable_array] = sym_variable_array,
  [sym_compound_variable_declaration] = sym_compound_variable_declaration,
  [sym_compound_value] = sym_compound_value,
  [sym_compound_boolean] = sym_compound_boolean,
  [sym_compound_array] = sym_compound_array,
  [sym_compound_step_block] = sym_compound_step_block,
  [sym_compound_step_body] = sym_compound_step_body,
  [sym_compound_assignment] = sym_compound_assignment,
  [sym_compound_assignment_value] = sym_compound_assignment_value,
  [sym_compound_expression] = sym_compound_expression,
  [sym_compound_additive_expr] = sym_compound_additive_expr,
  [sym_compound_multiplicative_expr] = sym_compound_multiplicative_expr,
  [sym_compound_primary_expr] = sym_compound_primary_expr,
  [sym_compound_array_access] = sym_compound_array_access,
  [sym_compound_for_loop] = sym_compound_for_loop,
  [sym_compound_if_block] = sym_compound_if_block,
  [sym_compound_statement] = sym_compound_statement,
  [sym_compound_array_assignment] = sym_compound_array_assignment,
  [sym_compound_condition] = sym_compound_condition,
  [sym_compound_comparison] = sym_compound_comparison,
  [sym_compound_function_call] = sym_compound_function_call,
  [sym_compound_argument_list] = sym_compound_argument_list,
  [sym_compound_script] = sym_compound_script,
  [sym_compound_variable_reference] = sym_compound_variable_reference,
  [sym_compound_end] = sym_compound_end,
  [sym_value] = sym_value,
  [sym_value_atom] = sym_value_atom,
  [sym_input_key] = sym_input_key,
  [sym_input_title] = sym_input_title,
  [sym__geom] = sym__geom,
  [sym_geom_line] = sym_geom_line,
  [sym_geom_block] = sym_geom_block,
  [sym_geom_line_types] = sym_geom_line_types,
  [sym_int_line] = sym_int_line,
  [sym_zmat_line1] = sym_zmat_line1,
  [sym_zmat_line2] = sym_zmat_line2,
  [sym_zmat_line3] = sym_zmat_line3,
  [sym_zmat_line4] = sym_zmat_line4,
  [sym_xyz_line] = sym_xyz_line,
  [sym_coord_value] = sym_coord_value,
  [sym_variable_ref] = sym_variable_ref,
  [sym_array] = sym_array,
  [sym_brace_block] = sym_brace_block,
  [sym_brace_content] = sym_brace_content,
  [sym_brace_value] = sym_brace_value,
  [sym_constraint_content] = sym_constraint_content,
  [sym_raw_content] = sym_raw_content,
  [sym_arg] = sym_arg,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_simple_line_repeat1] = aux_sym_simple_line_repeat1,
  [aux_sym_input_body_repeat1] = aux_sym_input_body_repeat1,
  [aux_sym_subblock_repeat1] = aux_sym_subblock_repeat1,
  [aux_sym_subblock_repeat2] = aux_sym_subblock_repeat2,
  [aux_sym_subblock_repeat3] = aux_sym_subblock_repeat3,
  [aux_sym_variable_array_repeat1] = aux_sym_variable_array_repeat1,
  [aux_sym_compound_variable_declaration_repeat1] = aux_sym_compound_variable_declaration_repeat1,
  [aux_sym_compound_array_repeat1] = aux_sym_compound_array_repeat1,
  [aux_sym_compound_step_body_repeat1] = aux_sym_compound_step_body_repeat1,
  [aux_sym_compound_for_loop_repeat1] = aux_sym_compound_for_loop_repeat1,
  [aux_sym_compound_argument_list_repeat1] = aux_sym_compound_argument_list_repeat1,
  [aux_sym_compound_script_repeat1] = aux_sym_compound_script_repeat1,
  [aux_sym_value_repeat1] = aux_sym_value_repeat1,
  [aux_sym_brace_content_repeat1] = aux_sym_brace_content_repeat1,
  [aux_sym_constraint_content_repeat1] = aux_sym_constraint_content_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_compound_variable_declaration_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_boolean_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_boolean_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_step_block_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_step_block_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_step_block_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_step_block_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_compound_for_loop_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_for_loop_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_for_loop_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_for_loop_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_for_loop_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_if_block_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_if_block_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_if_block_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_if_block_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_array_assignment_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_condition_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_condition_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_compound_script_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_script_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_script_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_AMP_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xyz] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gzmt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xyzfile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gzmtfile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_A] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_B] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_D] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_T] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_C] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_S] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_F] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_element] = {
    .visible = true,
    .named = true,
  },
  [sym_word] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_arg_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_line] = {
    .visible = true,
    .named = true,
  },
  [sym__input] = {
    .visible = false,
    .named = true,
  },
  [sym_input_line] = {
    .visible = true,
    .named = true,
  },
  [sym_input_block] = {
    .visible = true,
    .named = true,
  },
  [sym_input_body] = {
    .visible = true,
    .named = true,
  },
  [sym_subblock] = {
    .visible = true,
    .named = true,
  },
  [sym_kv_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_def] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_range] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_array] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_value] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_array] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_step_block] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_step_body] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_assignment_value] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_additive_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_multiplicative_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_primary_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_array_access] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_for_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_if_block] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_array_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_comparison] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_script] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_variable_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_end] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_value_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_input_key] = {
    .visible = true,
    .named = true,
  },
  [sym_input_title] = {
    .visible = true,
    .named = true,
  },
  [sym__geom] = {
    .visible = false,
    .named = true,
  },
  [sym_geom_line] = {
    .visible = true,
    .named = true,
  },
  [sym_geom_block] = {
    .visible = true,
    .named = true,
  },
  [sym_geom_line_types] = {
    .visible = true,
    .named = true,
  },
  [sym_int_line] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line1] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line2] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line3] = {
    .visible = true,
    .named = true,
  },
  [sym_zmat_line4] = {
    .visible = true,
    .named = true,
  },
  [sym_xyz_line] = {
    .visible = true,
    .named = true,
  },
  [sym_coord_value] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_block] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_content] = {
    .visible = true,
    .named = true,
  },
  [sym_brace_value] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_content] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_content] = {
    .visible = true,
    .named = true,
  },
  [sym_arg] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_simple_line_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_input_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subblock_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_step_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_for_loop_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_script_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_brace_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constraint_content_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_connect1 = 1,
  field_connect2 = 2,
  field_connect3 = 3,
  field_name = 4,
  field_zmat_atom1 = 5,
  field_zmat_atom2 = 6,
  field_zmat_atom3 = 7,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_connect1] = "connect1",
  [field_connect2] = "connect2",
  [field_connect3] = "connect3",
  [field_name] = "name",
  [field_zmat_atom1] = "zmat_atom1",
  [field_zmat_atom2] = "zmat_atom2",
  [field_zmat_atom3] = "zmat_atom3",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 3},
  [5] = {.index = 7, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_zmat_atom1, 1},
  [2] =
    {field_zmat_atom1, 1},
    {field_zmat_atom2, 3},
  [4] =
    {field_connect1, 1},
    {field_connect2, 2},
    {field_connect3, 3},
  [7] =
    {field_zmat_atom1, 1},
    {field_zmat_atom2, 3},
    {field_zmat_atom3, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 4,
  [6] = 6,
  [7] = 7,
  [8] = 7,
  [9] = 4,
  [10] = 7,
  [11] = 4,
  [12] = 7,
  [13] = 13,
  [14] = 14,
  [15] = 6,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 13,
  [23] = 23,
  [24] = 6,
  [25] = 17,
  [26] = 19,
  [27] = 20,
  [28] = 21,
  [29] = 13,
  [30] = 23,
  [31] = 19,
  [32] = 17,
  [33] = 19,
  [34] = 20,
  [35] = 21,
  [36] = 23,
  [37] = 17,
  [38] = 20,
  [39] = 21,
  [40] = 13,
  [41] = 23,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 53,
  [55] = 53,
  [56] = 53,
  [57] = 53,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 59,
  [63] = 60,
  [64] = 59,
  [65] = 65,
  [66] = 60,
  [67] = 60,
  [68] = 59,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 58,
  [73] = 61,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 71,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 79,
  [87] = 87,
  [88] = 88,
  [89] = 79,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 79,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 71,
  [108] = 71,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 102,
  [113] = 113,
  [114] = 104,
  [115] = 105,
  [116] = 106,
  [117] = 85,
  [118] = 70,
  [119] = 98,
  [120] = 58,
  [121] = 100,
  [122] = 103,
  [123] = 123,
  [124] = 61,
  [125] = 80,
  [126] = 96,
  [127] = 92,
  [128] = 81,
  [129] = 101,
  [130] = 58,
  [131] = 61,
  [132] = 74,
  [133] = 83,
  [134] = 84,
  [135] = 135,
  [136] = 88,
  [137] = 78,
  [138] = 87,
  [139] = 113,
  [140] = 113,
  [141] = 113,
  [142] = 90,
  [143] = 91,
  [144] = 94,
  [145] = 109,
  [146] = 84,
  [147] = 147,
  [148] = 148,
  [149] = 148,
  [150] = 150,
  [151] = 151,
  [152] = 123,
  [153] = 87,
  [154] = 78,
  [155] = 80,
  [156] = 74,
  [157] = 109,
  [158] = 81,
  [159] = 83,
  [160] = 88,
  [161] = 90,
  [162] = 91,
  [163] = 94,
  [164] = 123,
  [165] = 96,
  [166] = 102,
  [167] = 104,
  [168] = 105,
  [169] = 106,
  [170] = 85,
  [171] = 87,
  [172] = 70,
  [173] = 98,
  [174] = 78,
  [175] = 80,
  [176] = 100,
  [177] = 103,
  [178] = 74,
  [179] = 109,
  [180] = 81,
  [181] = 83,
  [182] = 182,
  [183] = 88,
  [184] = 90,
  [185] = 91,
  [186] = 92,
  [187] = 94,
  [188] = 96,
  [189] = 101,
  [190] = 102,
  [191] = 104,
  [192] = 105,
  [193] = 106,
  [194] = 85,
  [195] = 70,
  [196] = 98,
  [197] = 100,
  [198] = 103,
  [199] = 92,
  [200] = 101,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 204,
  [207] = 151,
  [208] = 204,
  [209] = 151,
  [210] = 204,
  [211] = 151,
  [212] = 147,
  [213] = 147,
  [214] = 147,
  [215] = 148,
  [216] = 148,
  [217] = 84,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 219,
  [222] = 219,
  [223] = 219,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 233,
  [239] = 233,
  [240] = 233,
  [241] = 233,
  [242] = 236,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 244,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 249,
  [253] = 251,
  [254] = 254,
  [255] = 255,
  [256] = 249,
  [257] = 251,
  [258] = 258,
  [259] = 249,
  [260] = 251,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 251,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 261,
  [269] = 269,
  [270] = 261,
  [271] = 261,
  [272] = 272,
  [273] = 261,
  [274] = 244,
  [275] = 244,
  [276] = 276,
  [277] = 244,
  [278] = 278,
  [279] = 249,
  [280] = 92,
  [281] = 232,
  [282] = 282,
  [283] = 283,
  [284] = 100,
  [285] = 285,
  [286] = 285,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 285,
  [291] = 70,
  [292] = 292,
  [293] = 285,
  [294] = 294,
  [295] = 98,
  [296] = 101,
  [297] = 297,
  [298] = 298,
  [299] = 85,
  [300] = 103,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 302,
  [305] = 303,
  [306] = 306,
  [307] = 302,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 303,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 302,
  [319] = 302,
  [320] = 303,
  [321] = 303,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 328,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 328,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 336,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 327,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 336,
  [356] = 356,
  [357] = 357,
  [358] = 327,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 336,
  [363] = 363,
  [364] = 364,
  [365] = 327,
  [366] = 366,
  [367] = 367,
  [368] = 327,
  [369] = 369,
  [370] = 370,
  [371] = 338,
  [372] = 363,
  [373] = 367,
  [374] = 370,
  [375] = 375,
  [376] = 376,
  [377] = 338,
  [378] = 363,
  [379] = 367,
  [380] = 370,
  [381] = 338,
  [382] = 363,
  [383] = 367,
  [384] = 370,
  [385] = 385,
  [386] = 236,
  [387] = 338,
  [388] = 367,
  [389] = 370,
  [390] = 390,
  [391] = 345,
  [392] = 322,
  [393] = 345,
  [394] = 322,
  [395] = 395,
  [396] = 345,
  [397] = 322,
  [398] = 322,
  [399] = 236,
  [400] = 328,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 385,
  [410] = 410,
  [411] = 411,
  [412] = 404,
  [413] = 404,
  [414] = 404,
  [415] = 410,
  [416] = 407,
  [417] = 332,
  [418] = 404,
  [419] = 419,
  [420] = 407,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 236,
  [426] = 408,
  [427] = 427,
  [428] = 423,
  [429] = 406,
  [430] = 236,
  [431] = 431,
  [432] = 410,
  [433] = 407,
  [434] = 410,
  [435] = 408,
  [436] = 408,
  [437] = 404,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 439,
  [449] = 446,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 444,
  [460] = 460,
  [461] = 445,
  [462] = 446,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 451,
  [467] = 457,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 447,
  [473] = 458,
  [474] = 474,
  [475] = 460,
  [476] = 445,
  [477] = 477,
  [478] = 450,
  [479] = 465,
  [480] = 439,
  [481] = 468,
  [482] = 482,
  [483] = 458,
  [484] = 484,
  [485] = 444,
  [486] = 486,
  [487] = 458,
  [488] = 488,
  [489] = 460,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 465,
  [494] = 494,
  [495] = 455,
  [496] = 456,
  [497] = 497,
  [498] = 444,
  [499] = 445,
  [500] = 500,
  [501] = 484,
  [502] = 446,
  [503] = 503,
  [504] = 464,
  [505] = 451,
  [506] = 457,
  [507] = 468,
  [508] = 469,
  [509] = 500,
  [510] = 484,
  [511] = 471,
  [512] = 447,
  [513] = 513,
  [514] = 514,
  [515] = 455,
  [516] = 439,
  [517] = 517,
  [518] = 500,
  [519] = 484,
  [520] = 520,
  [521] = 460,
  [522] = 470,
  [523] = 447,
  [524] = 524,
  [525] = 469,
  [526] = 526,
  [527] = 456,
  [528] = 446,
  [529] = 465,
  [530] = 455,
  [531] = 456,
  [532] = 532,
  [533] = 533,
  [534] = 488,
  [535] = 490,
  [536] = 491,
  [537] = 513,
  [538] = 444,
  [539] = 445,
  [540] = 446,
  [541] = 488,
  [542] = 490,
  [543] = 491,
  [544] = 513,
  [545] = 545,
  [546] = 464,
  [547] = 451,
  [548] = 488,
  [549] = 490,
  [550] = 491,
  [551] = 513,
  [552] = 457,
  [553] = 488,
  [554] = 490,
  [555] = 491,
  [556] = 468,
  [557] = 454,
  [558] = 517,
  [559] = 520,
  [560] = 560,
  [561] = 469,
  [562] = 471,
  [563] = 454,
  [564] = 517,
  [565] = 520,
  [566] = 560,
  [567] = 447,
  [568] = 568,
  [569] = 454,
  [570] = 517,
  [571] = 520,
  [572] = 560,
  [573] = 500,
  [574] = 438,
  [575] = 517,
  [576] = 520,
  [577] = 560,
  [578] = 545,
  [579] = 438,
  [580] = 442,
  [581] = 524,
  [582] = 545,
  [583] = 438,
  [584] = 442,
  [585] = 524,
  [586] = 545,
  [587] = 439,
  [588] = 442,
  [589] = 524,
  [590] = 545,
  [591] = 438,
  [592] = 442,
  [593] = 464,
  [594] = 594,
  [595] = 471,
  [596] = 560,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(85);
      ADVANCE_MAP(
        '!', 87,
        '"', 14,
        '#', 165,
        '%', 137,
        '&', 40,
        '(', 113,
        ')', 114,
        '*', 111,
        '+', 109,
        ',', 94,
        '-', 110,
        '/', 112,
        ';', 93,
        '<', 131,
        '=', 92,
        '>', 132,
        'A', 152,
        'B', 154,
        'C', 160,
        'D', 156,
        'E', 190,
        'F', 164,
        'I', 188,
        'S', 162,
        'T', 158,
        '[', 95,
        ']', 96,
        'a', 193,
        'c', 194,
        'd', 195,
        'e', 168,
        'f', 179,
        'g', 177,
        'i', 172,
        's', 201,
        't', 189,
        'x', 176,
        '{', 150,
        '}', 144,
        'N', 184,
        'n', 184,
        'O', 197,
        'o', 197,
        'R', 185,
        'r', 185,
        'V', 181,
        'v', 181,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(205);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 88,
        '"', 14,
        '#', 165,
        '&', 40,
        '-', 272,
        '=', 91,
        '[', 95,
        '{', 150,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(210);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(88);
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '&') ADVANCE(40);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(275);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(88);
      if (lookahead == '#') ADVANCE(165);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 86,
        '#', 165,
        '%', 137,
        '&', 40,
        '*', 111,
        '-', 83,
        ';', 93,
        ']', 96,
        '{', 150,
        'E', 235,
        'e', 235,
        'F', 244,
        'f', 244,
        'I', 230,
        'i', 230,
        'N', 222,
        'n', 222,
        'R', 228,
        'r', 228,
        'V', 214,
        'v', 214,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 86,
        '#', 165,
        '%', 137,
        '&', 40,
        '*', 111,
        ';', 93,
        'E', 242,
        'e', 242,
        'F', 244,
        'f', 244,
        'I', 230,
        'i', 230,
        'N', 222,
        'n', 222,
        'R', 228,
        'r', 228,
        'V', 214,
        'v', 214,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 86,
        '#', 165,
        '%', 137,
        '*', 111,
        '-', 272,
        'A', 151,
        'B', 153,
        'D', 155,
        'T', 157,
        '}', 144,
        'S', 79,
        's', 79,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 86,
        '#', 165,
        '%', 137,
        '*', 111,
        ';', 93,
        'E', 241,
        'e', 241,
        'F', 244,
        'f', 244,
        'I', 230,
        'i', 230,
        'N', 222,
        'n', 222,
        'R', 228,
        'r', 228,
        'V', 214,
        'v', 214,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 22,
        '#', 165,
        '(', 113,
        ')', 114,
        '*', 111,
        '+', 109,
        ',', 94,
        '-', 110,
        '/', 112,
        ';', 93,
        '<', 131,
        '=', 92,
        '>', 132,
        '[', 95,
        ']', 96,
        'e', 33,
        'g', 39,
        'i', 34,
        'x', 37,
        '}', 144,
        'A', 65,
        'a', 65,
        'D', 66,
        'd', 66,
        'F', 74,
        'f', 74,
        'O', 73,
        'o', 73,
        'S', 79,
        's', 79,
        'T', 57,
        't', 57,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(22);
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '<') ADVANCE(131);
      if (lookahead == '=') ADVANCE(92);
      if (lookahead == '>') ADVANCE(132);
      if (lookahead == 'e') ADVANCE(173);
      if (lookahead == '{') ADVANCE(150);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(204);
      END_STATE();
    case 10:
      if (lookahead == '"') ADVANCE(14);
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '&') ADVANCE(40);
      if (lookahead == '-') ADVANCE(272);
      if (lookahead == '=') ADVANCE(91);
      if (lookahead == '{') ADVANCE(150);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(210);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(14);
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '(') ADVANCE(113);
      if (lookahead == ')') ADVANCE(114);
      if (lookahead == '-') ADVANCE(272);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '"', 14,
        '#', 165,
        ',', 94,
        '-', 83,
        ';', 93,
        '[', 95,
        'e', 209,
        '{', 150,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '"', 14,
        '#', 165,
        '-', 272,
        '[', 95,
        ']', 96,
        'F', 215,
        'f', 215,
        'T', 254,
        't', 254,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(267);
      if (lookahead != 0) ADVANCE(14);
      END_STATE();
    case 15:
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '&') ADVANCE(40);
      if (lookahead == ',') ADVANCE(94);
      if (lookahead == ';') ADVANCE(93);
      if (lookahead == 'e') ADVANCE(209);
      if (lookahead == '{') ADVANCE(150);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 16:
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '&') ADVANCE(40);
      if (lookahead == '-') ADVANCE(272);
      if (lookahead == 'C') ADVANCE(159);
      if (lookahead == 'F') ADVANCE(163);
      if (lookahead == 'S') ADVANCE(161);
      if (lookahead == '}') ADVANCE(144);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 17:
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '&') ADVANCE(40);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(274);
      END_STATE();
    case 18:
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == 'e') ADVANCE(174);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(205);
      END_STATE();
    case 19:
      if (lookahead == '#') ADVANCE(165);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(245);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 20:
      if (lookahead == '#') ADVANCE(165);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(265);
      END_STATE();
    case 21:
      if (lookahead == '-') ADVANCE(82);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 22:
      if (lookahead == '=') ADVANCE(136);
      END_STATE();
    case 23:
      if (lookahead == '_') ADVANCE(76);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(77);
      END_STATE();
    case 24:
      if (lookahead == '_') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(62);
      END_STATE();
    case 25:
      if (lookahead == 'd') ADVANCE(89);
      END_STATE();
    case 26:
      if (lookahead == 'e') ADVANCE(148);
      END_STATE();
    case 27:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 28:
      if (lookahead == 'i') ADVANCE(30);
      END_STATE();
    case 29:
      if (lookahead == 'i') ADVANCE(31);
      END_STATE();
    case 30:
      if (lookahead == 'l') ADVANCE(26);
      END_STATE();
    case 31:
      if (lookahead == 'l') ADVANCE(27);
      END_STATE();
    case 32:
      if (lookahead == 'm') ADVANCE(36);
      END_STATE();
    case 33:
      if (lookahead == 'n') ADVANCE(25);
      END_STATE();
    case 34:
      if (lookahead == 'n') ADVANCE(35);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 36:
      if (lookahead == 't') ADVANCE(147);
      END_STATE();
    case 37:
      if (lookahead == 'y') ADVANCE(38);
      END_STATE();
    case 38:
      if (lookahead == 'z') ADVANCE(145);
      END_STATE();
    case 39:
      if (lookahead == 'z') ADVANCE(32);
      END_STATE();
    case 40:
      if (lookahead == '{') ADVANCE(143);
      END_STATE();
    case 41:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(42);
      END_STATE();
    case 42:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(59);
      END_STATE();
    case 43:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(129);
      END_STATE();
    case 44:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(127);
      END_STATE();
    case 45:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(105);
      END_STATE();
    case 46:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(138);
      END_STATE();
    case 47:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(108);
      END_STATE();
    case 48:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 49:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 50:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 51:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 52:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      END_STATE();
    case 53:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 54:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(71);
      END_STATE();
    case 55:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(72);
      END_STATE();
    case 56:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 57:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(48);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(118);
      END_STATE();
    case 58:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(41);
      END_STATE();
    case 59:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(52);
      END_STATE();
    case 60:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(117);
      END_STATE();
    case 61:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(123);
      END_STATE();
    case 62:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(45);
      END_STATE();
    case 63:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(46);
      END_STATE();
    case 64:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(47);
      END_STATE();
    case 65:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 66:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(119);
      END_STATE();
    case 67:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 68:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(80);
      END_STATE();
    case 69:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(68);
      END_STATE();
    case 70:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(24);
      END_STATE();
    case 71:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(103);
      END_STATE();
    case 72:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(106);
      END_STATE();
    case 73:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(130);
      END_STATE();
    case 74:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 75:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(51);
      END_STATE();
    case 76:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(78);
      END_STATE();
    case 77:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(54);
      END_STATE();
    case 78:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(55);
      END_STATE();
    case 79:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(53);
      END_STATE();
    case 80:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(63);
      END_STATE();
    case 81:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 82:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 83:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      END_STATE();
    case 84:
      if (eof) ADVANCE(85);
      ADVANCE_MAP(
        '!', 86,
        '#', 165,
        '%', 137,
        '&', 40,
        '*', 111,
        ',', 94,
        '-', 272,
        ';', 93,
        '{', 150,
        '}', 144,
        'E', 239,
        'e', 239,
        'F', 244,
        'f', 244,
        'I', 230,
        'i', 230,
        'N', 222,
        'n', 222,
        'R', 228,
        'r', 228,
        'V', 214,
        'v', 214,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(84);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(136);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(88);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_end);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(135);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(aux_sym_compound_variable_declaration_token1);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(aux_sym_compound_variable_declaration_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(aux_sym_compound_boolean_token1);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(aux_sym_compound_boolean_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(aux_sym_compound_boolean_token2);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(aux_sym_compound_boolean_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token1);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token2);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token3);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token3);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(aux_sym_compound_step_block_token4);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token1);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token2);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token3);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token4);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym_compound_for_loop_token5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token1);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token2);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token3);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token3);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(aux_sym_compound_if_block_token4);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(aux_sym_compound_array_assignment_token1);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(aux_sym_compound_array_assignment_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(aux_sym_compound_condition_token1);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(aux_sym_compound_condition_token2);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(133);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(134);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym_compound_script_token1);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(aux_sym_compound_script_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(aux_sym_compound_script_token2);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(aux_sym_compound_script_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(260);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(aux_sym_compound_script_token3);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_AMP_LBRACE);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_xyz);
      if (lookahead == 'f') ADVANCE(28);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_int);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_gzmt);
      if (lookahead == 'f') ADVANCE(29);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_xyzfile);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_gzmtfile);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_A);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_A);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(182);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_B);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_B);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_D);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_D);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(119);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_T);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_T);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(186);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(118);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(202);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_C);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_C);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(192);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_S);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_S);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(187);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_F);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_F);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(191);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(198);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(196);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(165);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_element);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'D') ADVANCE(140);
      if (lookahead == 'd') ADVANCE(89);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'N') ADVANCE(183);
      if (lookahead == 'n') ADVANCE(167);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(200);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'd') ADVANCE(89);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'd') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'm') ADVANCE(36);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(175);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(121);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(170);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(264);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(206);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'n') ADVANCE(169);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'y') ADVANCE(178);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'z') ADVANCE(171);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(166);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'z') ADVANCE(145);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(191);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(198);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(196);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(44);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(199);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(129);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(140);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(203);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(180);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(121);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(186);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(118);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(202);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(200);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(183);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(69);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(182);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(192);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(119);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(130);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(115);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(49);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(187);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(50);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_element);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(23);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_element);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(264);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(206);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_element);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(166);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym_element);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '_') ADVANCE(257);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(258);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'd') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'n') ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '"' ||
          lookahead == '-') ADVANCE(266);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(211);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(210);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '"' ||
          lookahead == '-') ADVANCE(266);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(211);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(216);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(218);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(252);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(237);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(236);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(141);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(139);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(233);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(232);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(263);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(248);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(98);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(125);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(100);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(213);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(249);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(122);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(126);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(246);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(231);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(212);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(255);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(224);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(256);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(250);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(217);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(142);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(221);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(219);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(251);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(238);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(253);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(262);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(104);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(107);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(247);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(116);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(234);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(120);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(261);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(225);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(227);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(259);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(223);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(229);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(240);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(226);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(243);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(207);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_word);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(264);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(sym_string);
      if (lookahead == '"' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(266);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(265);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(sym_string);
      if (lookahead == '"' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(sym_quoted_string);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '-') ADVANCE(273);
      if (lookahead == '.') ADVANCE(81);
      if (lookahead == 'e') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '.') ADVANCE(81);
      if (lookahead == 'e') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'e') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(sym_float);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '-') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(274);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_arg_token1);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(275);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 84},
  [2] = {.lex_state = 84},
  [3] = {.lex_state = 84},
  [4] = {.lex_state = 4},
  [5] = {.lex_state = 4},
  [6] = {.lex_state = 4},
  [7] = {.lex_state = 4},
  [8] = {.lex_state = 4},
  [9] = {.lex_state = 4},
  [10] = {.lex_state = 4},
  [11] = {.lex_state = 4},
  [12] = {.lex_state = 4},
  [13] = {.lex_state = 5},
  [14] = {.lex_state = 84},
  [15] = {.lex_state = 7},
  [16] = {.lex_state = 84},
  [17] = {.lex_state = 7},
  [18] = {.lex_state = 84},
  [19] = {.lex_state = 5},
  [20] = {.lex_state = 7},
  [21] = {.lex_state = 7},
  [22] = {.lex_state = 5},
  [23] = {.lex_state = 7},
  [24] = {.lex_state = 5},
  [25] = {.lex_state = 7},
  [26] = {.lex_state = 5},
  [27] = {.lex_state = 7},
  [28] = {.lex_state = 7},
  [29] = {.lex_state = 5},
  [30] = {.lex_state = 7},
  [31] = {.lex_state = 5},
  [32] = {.lex_state = 7},
  [33] = {.lex_state = 5},
  [34] = {.lex_state = 7},
  [35] = {.lex_state = 7},
  [36] = {.lex_state = 7},
  [37] = {.lex_state = 7},
  [38] = {.lex_state = 7},
  [39] = {.lex_state = 7},
  [40] = {.lex_state = 5},
  [41] = {.lex_state = 7},
  [42] = {.lex_state = 9},
  [43] = {.lex_state = 8},
  [44] = {.lex_state = 8},
  [45] = {.lex_state = 8},
  [46] = {.lex_state = 8},
  [47] = {.lex_state = 8},
  [48] = {.lex_state = 8},
  [49] = {.lex_state = 8},
  [50] = {.lex_state = 8},
  [51] = {.lex_state = 8},
  [52] = {.lex_state = 8},
  [53] = {.lex_state = 12},
  [54] = {.lex_state = 12},
  [55] = {.lex_state = 12},
  [56] = {.lex_state = 12},
  [57] = {.lex_state = 12},
  [58] = {.lex_state = 84},
  [59] = {.lex_state = 6},
  [60] = {.lex_state = 6},
  [61] = {.lex_state = 84},
  [62] = {.lex_state = 6},
  [63] = {.lex_state = 6},
  [64] = {.lex_state = 6},
  [65] = {.lex_state = 6},
  [66] = {.lex_state = 6},
  [67] = {.lex_state = 6},
  [68] = {.lex_state = 6},
  [69] = {.lex_state = 6},
  [70] = {.lex_state = 84},
  [71] = {.lex_state = 11},
  [72] = {.lex_state = 4},
  [73] = {.lex_state = 4},
  [74] = {.lex_state = 84},
  [75] = {.lex_state = 11},
  [76] = {.lex_state = 11},
  [77] = {.lex_state = 84},
  [78] = {.lex_state = 84},
  [79] = {.lex_state = 11},
  [80] = {.lex_state = 84},
  [81] = {.lex_state = 84},
  [82] = {.lex_state = 11},
  [83] = {.lex_state = 84},
  [84] = {.lex_state = 84},
  [85] = {.lex_state = 84},
  [86] = {.lex_state = 11},
  [87] = {.lex_state = 84},
  [88] = {.lex_state = 84},
  [89] = {.lex_state = 11},
  [90] = {.lex_state = 84},
  [91] = {.lex_state = 84},
  [92] = {.lex_state = 84},
  [93] = {.lex_state = 10},
  [94] = {.lex_state = 84},
  [95] = {.lex_state = 84},
  [96] = {.lex_state = 84},
  [97] = {.lex_state = 84},
  [98] = {.lex_state = 84},
  [99] = {.lex_state = 11},
  [100] = {.lex_state = 84},
  [101] = {.lex_state = 84},
  [102] = {.lex_state = 84},
  [103] = {.lex_state = 84},
  [104] = {.lex_state = 84},
  [105] = {.lex_state = 84},
  [106] = {.lex_state = 84},
  [107] = {.lex_state = 11},
  [108] = {.lex_state = 11},
  [109] = {.lex_state = 84},
  [110] = {.lex_state = 12},
  [111] = {.lex_state = 12},
  [112] = {.lex_state = 4},
  [113] = {.lex_state = 11},
  [114] = {.lex_state = 4},
  [115] = {.lex_state = 4},
  [116] = {.lex_state = 4},
  [117] = {.lex_state = 4},
  [118] = {.lex_state = 4},
  [119] = {.lex_state = 4},
  [120] = {.lex_state = 7},
  [121] = {.lex_state = 4},
  [122] = {.lex_state = 4},
  [123] = {.lex_state = 4},
  [124] = {.lex_state = 7},
  [125] = {.lex_state = 4},
  [126] = {.lex_state = 4},
  [127] = {.lex_state = 4},
  [128] = {.lex_state = 4},
  [129] = {.lex_state = 4},
  [130] = {.lex_state = 5},
  [131] = {.lex_state = 5},
  [132] = {.lex_state = 4},
  [133] = {.lex_state = 4},
  [134] = {.lex_state = 4},
  [135] = {.lex_state = 10},
  [136] = {.lex_state = 4},
  [137] = {.lex_state = 4},
  [138] = {.lex_state = 4},
  [139] = {.lex_state = 11},
  [140] = {.lex_state = 11},
  [141] = {.lex_state = 11},
  [142] = {.lex_state = 4},
  [143] = {.lex_state = 4},
  [144] = {.lex_state = 4},
  [145] = {.lex_state = 4},
  [146] = {.lex_state = 7},
  [147] = {.lex_state = 11},
  [148] = {.lex_state = 11},
  [149] = {.lex_state = 11},
  [150] = {.lex_state = 11},
  [151] = {.lex_state = 11},
  [152] = {.lex_state = 7},
  [153] = {.lex_state = 7},
  [154] = {.lex_state = 7},
  [155] = {.lex_state = 7},
  [156] = {.lex_state = 7},
  [157] = {.lex_state = 7},
  [158] = {.lex_state = 7},
  [159] = {.lex_state = 7},
  [160] = {.lex_state = 7},
  [161] = {.lex_state = 7},
  [162] = {.lex_state = 7},
  [163] = {.lex_state = 7},
  [164] = {.lex_state = 5},
  [165] = {.lex_state = 7},
  [166] = {.lex_state = 7},
  [167] = {.lex_state = 7},
  [168] = {.lex_state = 7},
  [169] = {.lex_state = 7},
  [170] = {.lex_state = 7},
  [171] = {.lex_state = 5},
  [172] = {.lex_state = 7},
  [173] = {.lex_state = 7},
  [174] = {.lex_state = 5},
  [175] = {.lex_state = 5},
  [176] = {.lex_state = 7},
  [177] = {.lex_state = 7},
  [178] = {.lex_state = 5},
  [179] = {.lex_state = 5},
  [180] = {.lex_state = 5},
  [181] = {.lex_state = 5},
  [182] = {.lex_state = 10},
  [183] = {.lex_state = 5},
  [184] = {.lex_state = 5},
  [185] = {.lex_state = 5},
  [186] = {.lex_state = 7},
  [187] = {.lex_state = 5},
  [188] = {.lex_state = 5},
  [189] = {.lex_state = 7},
  [190] = {.lex_state = 5},
  [191] = {.lex_state = 5},
  [192] = {.lex_state = 5},
  [193] = {.lex_state = 5},
  [194] = {.lex_state = 5},
  [195] = {.lex_state = 5},
  [196] = {.lex_state = 5},
  [197] = {.lex_state = 5},
  [198] = {.lex_state = 5},
  [199] = {.lex_state = 5},
  [200] = {.lex_state = 5},
  [201] = {.lex_state = 13},
  [202] = {.lex_state = 11},
  [203] = {.lex_state = 11},
  [204] = {.lex_state = 11},
  [205] = {.lex_state = 11},
  [206] = {.lex_state = 11},
  [207] = {.lex_state = 11},
  [208] = {.lex_state = 11},
  [209] = {.lex_state = 11},
  [210] = {.lex_state = 11},
  [211] = {.lex_state = 11},
  [212] = {.lex_state = 11},
  [213] = {.lex_state = 11},
  [214] = {.lex_state = 11},
  [215] = {.lex_state = 11},
  [216] = {.lex_state = 11},
  [217] = {.lex_state = 5},
  [218] = {.lex_state = 13},
  [219] = {.lex_state = 13},
  [220] = {.lex_state = 6},
  [221] = {.lex_state = 13},
  [222] = {.lex_state = 13},
  [223] = {.lex_state = 13},
  [224] = {.lex_state = 1},
  [225] = {.lex_state = 16},
  [226] = {.lex_state = 11},
  [227] = {.lex_state = 16},
  [228] = {.lex_state = 18},
  [229] = {.lex_state = 10},
  [230] = {.lex_state = 11},
  [231] = {.lex_state = 1},
  [232] = {.lex_state = 10},
  [233] = {.lex_state = 18},
  [234] = {.lex_state = 18},
  [235] = {.lex_state = 9},
  [236] = {.lex_state = 15},
  [237] = {.lex_state = 84},
  [238] = {.lex_state = 18},
  [239] = {.lex_state = 18},
  [240] = {.lex_state = 18},
  [241] = {.lex_state = 18},
  [242] = {.lex_state = 16},
  [243] = {.lex_state = 84},
  [244] = {.lex_state = 8},
  [245] = {.lex_state = 4},
  [246] = {.lex_state = 4},
  [247] = {.lex_state = 84},
  [248] = {.lex_state = 8},
  [249] = {.lex_state = 2},
  [250] = {.lex_state = 12},
  [251] = {.lex_state = 2},
  [252] = {.lex_state = 2},
  [253] = {.lex_state = 2},
  [254] = {.lex_state = 12},
  [255] = {.lex_state = 12},
  [256] = {.lex_state = 2},
  [257] = {.lex_state = 2},
  [258] = {.lex_state = 2},
  [259] = {.lex_state = 2},
  [260] = {.lex_state = 2},
  [261] = {.lex_state = 18},
  [262] = {.lex_state = 4},
  [263] = {.lex_state = 4},
  [264] = {.lex_state = 2},
  [265] = {.lex_state = 4},
  [266] = {.lex_state = 4},
  [267] = {.lex_state = 4},
  [268] = {.lex_state = 18},
  [269] = {.lex_state = 12},
  [270] = {.lex_state = 18},
  [271] = {.lex_state = 18},
  [272] = {.lex_state = 84},
  [273] = {.lex_state = 18},
  [274] = {.lex_state = 8},
  [275] = {.lex_state = 8},
  [276] = {.lex_state = 4},
  [277] = {.lex_state = 8},
  [278] = {.lex_state = 4},
  [279] = {.lex_state = 2},
  [280] = {.lex_state = 6},
  [281] = {.lex_state = 12},
  [282] = {.lex_state = 18},
  [283] = {.lex_state = 18},
  [284] = {.lex_state = 6},
  [285] = {.lex_state = 0},
  [286] = {.lex_state = 0},
  [287] = {.lex_state = 12},
  [288] = {.lex_state = 12},
  [289] = {.lex_state = 84},
  [290] = {.lex_state = 0},
  [291] = {.lex_state = 6},
  [292] = {.lex_state = 12},
  [293] = {.lex_state = 0},
  [294] = {.lex_state = 12},
  [295] = {.lex_state = 6},
  [296] = {.lex_state = 6},
  [297] = {.lex_state = 12},
  [298] = {.lex_state = 12},
  [299] = {.lex_state = 6},
  [300] = {.lex_state = 6},
  [301] = {.lex_state = 12},
  [302] = {.lex_state = 18},
  [303] = {.lex_state = 18},
  [304] = {.lex_state = 18},
  [305] = {.lex_state = 18},
  [306] = {.lex_state = 84},
  [307] = {.lex_state = 18},
  [308] = {.lex_state = 12},
  [309] = {.lex_state = 12},
  [310] = {.lex_state = 12},
  [311] = {.lex_state = 18},
  [312] = {.lex_state = 18},
  [313] = {.lex_state = 18},
  [314] = {.lex_state = 12},
  [315] = {.lex_state = 12},
  [316] = {.lex_state = 84},
  [317] = {.lex_state = 12},
  [318] = {.lex_state = 18},
  [319] = {.lex_state = 18},
  [320] = {.lex_state = 18},
  [321] = {.lex_state = 18},
  [322] = {.lex_state = 5},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 84},
  [327] = {.lex_state = 17},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 12},
  [331] = {.lex_state = 12},
  [332] = {.lex_state = 4},
  [333] = {.lex_state = 8},
  [334] = {.lex_state = 18},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 0},
  [337] = {.lex_state = 0},
  [338] = {.lex_state = 5},
  [339] = {.lex_state = 4},
  [340] = {.lex_state = 0},
  [341] = {.lex_state = 18},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 8},
  [344] = {.lex_state = 84},
  [345] = {.lex_state = 11},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 12},
  [348] = {.lex_state = 18},
  [349] = {.lex_state = 8},
  [350] = {.lex_state = 18},
  [351] = {.lex_state = 17},
  [352] = {.lex_state = 18},
  [353] = {.lex_state = 4},
  [354] = {.lex_state = 12},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 12},
  [357] = {.lex_state = 12},
  [358] = {.lex_state = 17},
  [359] = {.lex_state = 0},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 0},
  [362] = {.lex_state = 0},
  [363] = {.lex_state = 8},
  [364] = {.lex_state = 8},
  [365] = {.lex_state = 17},
  [366] = {.lex_state = 0},
  [367] = {.lex_state = 18},
  [368] = {.lex_state = 17},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 18},
  [371] = {.lex_state = 5},
  [372] = {.lex_state = 8},
  [373] = {.lex_state = 18},
  [374] = {.lex_state = 18},
  [375] = {.lex_state = 18},
  [376] = {.lex_state = 2},
  [377] = {.lex_state = 5},
  [378] = {.lex_state = 8},
  [379] = {.lex_state = 18},
  [380] = {.lex_state = 18},
  [381] = {.lex_state = 5},
  [382] = {.lex_state = 8},
  [383] = {.lex_state = 18},
  [384] = {.lex_state = 18},
  [385] = {.lex_state = 4},
  [386] = {.lex_state = 4},
  [387] = {.lex_state = 5},
  [388] = {.lex_state = 18},
  [389] = {.lex_state = 18},
  [390] = {.lex_state = 12},
  [391] = {.lex_state = 11},
  [392] = {.lex_state = 5},
  [393] = {.lex_state = 11},
  [394] = {.lex_state = 5},
  [395] = {.lex_state = 4},
  [396] = {.lex_state = 11},
  [397] = {.lex_state = 5},
  [398] = {.lex_state = 5},
  [399] = {.lex_state = 2},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 11},
  [405] = {.lex_state = 3},
  [406] = {.lex_state = 11},
  [407] = {.lex_state = 84},
  [408] = {.lex_state = 11},
  [409] = {.lex_state = 3},
  [410] = {.lex_state = 11},
  [411] = {.lex_state = 0},
  [412] = {.lex_state = 11},
  [413] = {.lex_state = 11},
  [414] = {.lex_state = 11},
  [415] = {.lex_state = 11},
  [416] = {.lex_state = 84},
  [417] = {.lex_state = 3},
  [418] = {.lex_state = 11},
  [419] = {.lex_state = 3},
  [420] = {.lex_state = 84},
  [421] = {.lex_state = 19},
  [422] = {.lex_state = 11},
  [423] = {.lex_state = 20},
  [424] = {.lex_state = 3},
  [425] = {.lex_state = 3},
  [426] = {.lex_state = 11},
  [427] = {.lex_state = 5},
  [428] = {.lex_state = 20},
  [429] = {.lex_state = 11},
  [430] = {.lex_state = 17},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 11},
  [433] = {.lex_state = 84},
  [434] = {.lex_state = 11},
  [435] = {.lex_state = 11},
  [436] = {.lex_state = 11},
  [437] = {.lex_state = 11},
  [438] = {.lex_state = 5},
  [439] = {.lex_state = 1},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 4},
  [442] = {.lex_state = 5},
  [443] = {.lex_state = 5},
  [444] = {.lex_state = 1},
  [445] = {.lex_state = 8},
  [446] = {.lex_state = 0},
  [447] = {.lex_state = 1},
  [448] = {.lex_state = 1},
  [449] = {.lex_state = 0},
  [450] = {.lex_state = 0},
  [451] = {.lex_state = 0},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 5},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 8},
  [456] = {.lex_state = 8},
  [457] = {.lex_state = 0},
  [458] = {.lex_state = 0},
  [459] = {.lex_state = 1},
  [460] = {.lex_state = 8},
  [461] = {.lex_state = 8},
  [462] = {.lex_state = 0},
  [463] = {.lex_state = 1},
  [464] = {.lex_state = 0},
  [465] = {.lex_state = 8},
  [466] = {.lex_state = 0},
  [467] = {.lex_state = 0},
  [468] = {.lex_state = 0},
  [469] = {.lex_state = 0},
  [470] = {.lex_state = 0},
  [471] = {.lex_state = 0},
  [472] = {.lex_state = 1},
  [473] = {.lex_state = 0},
  [474] = {.lex_state = 1},
  [475] = {.lex_state = 8},
  [476] = {.lex_state = 8},
  [477] = {.lex_state = 0},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 8},
  [480] = {.lex_state = 1},
  [481] = {.lex_state = 0},
  [482] = {.lex_state = 5},
  [483] = {.lex_state = 0},
  [484] = {.lex_state = 0},
  [485] = {.lex_state = 1},
  [486] = {.lex_state = 0},
  [487] = {.lex_state = 0},
  [488] = {.lex_state = 1},
  [489] = {.lex_state = 8},
  [490] = {.lex_state = 1},
  [491] = {.lex_state = 1},
  [492] = {.lex_state = 11},
  [493] = {.lex_state = 8},
  [494] = {.lex_state = 0},
  [495] = {.lex_state = 8},
  [496] = {.lex_state = 8},
  [497] = {.lex_state = 1},
  [498] = {.lex_state = 1},
  [499] = {.lex_state = 8},
  [500] = {.lex_state = 0},
  [501] = {.lex_state = 0},
  [502] = {.lex_state = 0},
  [503] = {.lex_state = 4},
  [504] = {.lex_state = 0},
  [505] = {.lex_state = 0},
  [506] = {.lex_state = 0},
  [507] = {.lex_state = 0},
  [508] = {.lex_state = 0},
  [509] = {.lex_state = 0},
  [510] = {.lex_state = 0},
  [511] = {.lex_state = 0},
  [512] = {.lex_state = 1},
  [513] = {.lex_state = 8},
  [514] = {.lex_state = 0},
  [515] = {.lex_state = 8},
  [516] = {.lex_state = 1},
  [517] = {.lex_state = 5},
  [518] = {.lex_state = 0},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 5},
  [521] = {.lex_state = 8},
  [522] = {.lex_state = 0},
  [523] = {.lex_state = 1},
  [524] = {.lex_state = 8},
  [525] = {.lex_state = 0},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 8},
  [528] = {.lex_state = 0},
  [529] = {.lex_state = 8},
  [530] = {.lex_state = 8},
  [531] = {.lex_state = 8},
  [532] = {.lex_state = 0},
  [533] = {.lex_state = 8},
  [534] = {.lex_state = 1},
  [535] = {.lex_state = 1},
  [536] = {.lex_state = 1},
  [537] = {.lex_state = 8},
  [538] = {.lex_state = 1},
  [539] = {.lex_state = 8},
  [540] = {.lex_state = 0},
  [541] = {.lex_state = 1},
  [542] = {.lex_state = 1},
  [543] = {.lex_state = 1},
  [544] = {.lex_state = 8},
  [545] = {.lex_state = 5},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 0},
  [548] = {.lex_state = 1},
  [549] = {.lex_state = 1},
  [550] = {.lex_state = 1},
  [551] = {.lex_state = 8},
  [552] = {.lex_state = 0},
  [553] = {.lex_state = 1},
  [554] = {.lex_state = 1},
  [555] = {.lex_state = 1},
  [556] = {.lex_state = 0},
  [557] = {.lex_state = 0},
  [558] = {.lex_state = 5},
  [559] = {.lex_state = 5},
  [560] = {.lex_state = 5},
  [561] = {.lex_state = 0},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 5},
  [565] = {.lex_state = 5},
  [566] = {.lex_state = 5},
  [567] = {.lex_state = 1},
  [568] = {.lex_state = 4},
  [569] = {.lex_state = 0},
  [570] = {.lex_state = 5},
  [571] = {.lex_state = 5},
  [572] = {.lex_state = 5},
  [573] = {.lex_state = 0},
  [574] = {.lex_state = 5},
  [575] = {.lex_state = 5},
  [576] = {.lex_state = 5},
  [577] = {.lex_state = 5},
  [578] = {.lex_state = 5},
  [579] = {.lex_state = 5},
  [580] = {.lex_state = 5},
  [581] = {.lex_state = 8},
  [582] = {.lex_state = 5},
  [583] = {.lex_state = 5},
  [584] = {.lex_state = 5},
  [585] = {.lex_state = 8},
  [586] = {.lex_state = 5},
  [587] = {.lex_state = 1},
  [588] = {.lex_state = 5},
  [589] = {.lex_state = 8},
  [590] = {.lex_state = 5},
  [591] = {.lex_state = 5},
  [592] = {.lex_state = 5},
  [593] = {.lex_state = 0},
  [594] = {.lex_state = 0},
  [595] = {.lex_state = 0},
  [596] = {.lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [aux_sym_compound_variable_declaration_token1] = ACTIONS(1),
    [aux_sym_compound_boolean_token1] = ACTIONS(1),
    [aux_sym_compound_boolean_token2] = ACTIONS(1),
    [aux_sym_compound_step_block_token1] = ACTIONS(1),
    [aux_sym_compound_step_block_token2] = ACTIONS(1),
    [aux_sym_compound_step_block_token3] = ACTIONS(1),
    [aux_sym_compound_step_block_token4] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_compound_for_loop_token1] = ACTIONS(1),
    [aux_sym_compound_for_loop_token2] = ACTIONS(1),
    [aux_sym_compound_for_loop_token3] = ACTIONS(1),
    [aux_sym_compound_for_loop_token4] = ACTIONS(1),
    [aux_sym_compound_if_block_token1] = ACTIONS(1),
    [aux_sym_compound_if_block_token2] = ACTIONS(1),
    [aux_sym_compound_if_block_token3] = ACTIONS(1),
    [aux_sym_compound_array_assignment_token1] = ACTIONS(1),
    [aux_sym_compound_condition_token1] = ACTIONS(1),
    [aux_sym_compound_condition_token2] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [aux_sym_compound_script_token1] = ACTIONS(1),
    [aux_sym_compound_script_token2] = ACTIONS(1),
    [anon_sym_AMP_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_xyz] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_gzmt] = ACTIONS(1),
    [anon_sym_xyzfile] = ACTIONS(1),
    [anon_sym_gzmtfile] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_A] = ACTIONS(1),
    [anon_sym_B] = ACTIONS(1),
    [anon_sym_D] = ACTIONS(1),
    [anon_sym_T] = ACTIONS(1),
    [anon_sym_C] = ACTIONS(1),
    [anon_sym_S] = ACTIONS(1),
    [anon_sym_F] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_element] = ACTIONS(1),
    [sym_quoted_string] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(526),
    [sym_simple_line] = STATE(2),
    [sym__input] = STATE(2),
    [sym_input_line] = STATE(2),
    [sym_input_block] = STATE(2),
    [sym_variable_name] = STATE(336),
    [sym_compound_variable_declaration] = STATE(2),
    [sym_compound_step_block] = STATE(2),
    [sym_compound_assignment] = STATE(2),
    [sym_compound_array_access] = STATE(573),
    [sym_compound_for_loop] = STATE(2),
    [sym_compound_if_block] = STATE(2),
    [sym_compound_array_assignment] = STATE(2),
    [sym_compound_function_call] = STATE(2),
    [sym_compound_script] = STATE(2),
    [sym_compound_end] = STATE(2),
    [sym_input_title] = STATE(55),
    [sym__geom] = STATE(2),
    [sym_geom_line] = STATE(2),
    [sym_geom_block] = STATE(2),
    [aux_sym_source_file_repeat1] = STATE(2),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_BANG] = ACTIONS(7),
    [aux_sym_compound_variable_declaration_token1] = ACTIONS(9),
    [aux_sym_compound_step_block_token1] = ACTIONS(11),
    [aux_sym_compound_step_block_token3] = ACTIONS(13),
    [anon_sym_STAR] = ACTIONS(15),
    [aux_sym_compound_for_loop_token1] = ACTIONS(17),
    [aux_sym_compound_if_block_token1] = ACTIONS(19),
    [aux_sym_compound_array_assignment_token1] = ACTIONS(21),
    [anon_sym_PERCENT] = ACTIONS(23),
    [aux_sym_compound_script_token2] = ACTIONS(25),
    [aux_sym_compound_script_token3] = ACTIONS(25),
    [sym_comment] = ACTIONS(3),
    [sym_word] = ACTIONS(27),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_BANG,
    ACTIONS(9), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(11), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(13), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(17), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(19), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(21), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(23), 1,
      anon_sym_PERCENT,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(29), 1,
      ts_builtin_sym_end,
    STATE(55), 1,
      sym_input_title,
    STATE(336), 1,
      sym_variable_name,
    STATE(573), 1,
      sym_compound_array_access,
    ACTIONS(25), 2,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
    STATE(3), 17,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym_compound_script,
      sym_compound_end,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_source_file_repeat1,
  [69] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      ts_builtin_sym_end,
    ACTIONS(33), 1,
      anon_sym_BANG,
    ACTIONS(36), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(39), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(42), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(45), 1,
      anon_sym_STAR,
    ACTIONS(48), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(51), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(54), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(57), 1,
      anon_sym_PERCENT,
    ACTIONS(63), 1,
      sym_word,
    STATE(55), 1,
      sym_input_title,
    STATE(336), 1,
      sym_variable_name,
    STATE(573), 1,
      sym_compound_array_access,
    ACTIONS(60), 2,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
    STATE(3), 17,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym_compound_script,
      sym_compound_end,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_source_file_repeat1,
  [138] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(80), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(82), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(6), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [207] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(88), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(90), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(6), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [276] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(92), 1,
      anon_sym_BANG,
    ACTIONS(95), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(98), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(101), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(104), 1,
      anon_sym_STAR,
    ACTIONS(107), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(110), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(115), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(118), 1,
      anon_sym_PERCENT,
    ACTIONS(121), 1,
      sym_word,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    ACTIONS(113), 2,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
    STATE(6), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [343] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(124), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(126), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(5), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [412] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(128), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(130), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(9), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [481] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(132), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(134), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(6), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [550] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(136), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(138), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(11), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [619] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(140), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(142), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(6), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [688] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(66), 1,
      anon_sym_BANG,
    ACTIONS(68), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(70), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(72), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(74), 1,
      anon_sym_STAR,
    ACTIONS(76), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(78), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(84), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(144), 1,
      aux_sym_compound_if_block_token3,
    ACTIONS(146), 1,
      aux_sym_compound_if_block_token4,
    STATE(53), 1,
      sym_input_title,
    STATE(346), 1,
      sym_variable_name,
    STATE(500), 1,
      sym_compound_array_access,
    STATE(4), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(123), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [757] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(160), 1,
      aux_sym_compound_for_loop_token5,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(24), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [823] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_BANG,
    ACTIONS(9), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(11), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(13), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(17), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(19), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(21), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    STATE(55), 1,
      sym_input_title,
    STATE(336), 1,
      sym_variable_name,
    STATE(573), 1,
      sym_compound_array_access,
    ACTIONS(166), 2,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
    STATE(16), 15,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_script_repeat1,
  [887] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(118), 1,
      anon_sym_PERCENT,
    ACTIONS(121), 1,
      sym_word,
    ACTIONS(168), 1,
      anon_sym_BANG,
    ACTIONS(171), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(174), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(177), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(180), 1,
      anon_sym_STAR,
    ACTIONS(183), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(186), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(189), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [953] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(192), 1,
      anon_sym_BANG,
    ACTIONS(195), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(198), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(201), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(204), 1,
      anon_sym_STAR,
    ACTIONS(207), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(210), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(213), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(216), 1,
      anon_sym_PERCENT,
    ACTIONS(221), 1,
      sym_word,
    STATE(55), 1,
      sym_input_title,
    STATE(336), 1,
      sym_variable_name,
    STATE(573), 1,
      sym_compound_array_access,
    ACTIONS(219), 2,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
    STATE(16), 15,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_script_repeat1,
  [1017] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(90), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(20), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1083] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_BANG,
    ACTIONS(9), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(11), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(13), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(15), 1,
      anon_sym_STAR,
    ACTIONS(17), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(19), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(21), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    STATE(55), 1,
      sym_input_title,
    STATE(336), 1,
      sym_variable_name,
    STATE(573), 1,
      sym_compound_array_access,
    ACTIONS(240), 2,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
    STATE(14), 15,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_script_repeat1,
  [1147] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(242), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(22), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1213] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(244), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1279] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(244), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(23), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1345] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(246), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(24), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1411] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(248), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1477] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      aux_sym_compound_for_loop_token5,
    ACTIONS(118), 1,
      anon_sym_PERCENT,
    ACTIONS(121), 1,
      sym_word,
    ACTIONS(250), 1,
      anon_sym_BANG,
    ACTIONS(253), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(256), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(259), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(262), 1,
      anon_sym_STAR,
    ACTIONS(265), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(268), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(271), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(24), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1543] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(134), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(27), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1609] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(274), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(29), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1675] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(276), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1741] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(276), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(30), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1807] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(278), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(24), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1873] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(280), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [1939] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(282), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(40), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2005] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(142), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(34), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(284), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(13), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2137] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(286), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2203] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(286), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(36), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2269] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(288), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2335] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(82), 1,
      aux_sym_compound_if_block_token4,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(38), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2401] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(290), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2467] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(290), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(41), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2533] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(148), 1,
      anon_sym_BANG,
    ACTIONS(150), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(152), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(154), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(156), 1,
      anon_sym_STAR,
    ACTIONS(158), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(162), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(164), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(292), 1,
      aux_sym_compound_for_loop_token5,
    STATE(57), 1,
      sym_input_title,
    STATE(362), 1,
      sym_variable_name,
    STATE(518), 1,
      sym_compound_array_access,
    STATE(24), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(164), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2599] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym_word,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(224), 1,
      anon_sym_BANG,
    ACTIONS(226), 1,
      aux_sym_compound_variable_declaration_token1,
    ACTIONS(228), 1,
      aux_sym_compound_step_block_token1,
    ACTIONS(230), 1,
      aux_sym_compound_step_block_token3,
    ACTIONS(232), 1,
      anon_sym_STAR,
    ACTIONS(234), 1,
      aux_sym_compound_for_loop_token1,
    ACTIONS(236), 1,
      aux_sym_compound_if_block_token1,
    ACTIONS(238), 1,
      aux_sym_compound_array_assignment_token1,
    ACTIONS(294), 1,
      aux_sym_compound_if_block_token4,
    STATE(56), 1,
      sym_input_title,
    STATE(355), 1,
      sym_variable_name,
    STATE(509), 1,
      sym_compound_array_access,
    STATE(15), 2,
      sym_compound_statement,
      aux_sym_compound_for_loop_repeat1,
    STATE(152), 14,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym_compound_variable_declaration,
      sym_compound_step_block,
      sym_compound_assignment,
      sym_compound_for_loop,
      sym_compound_if_block,
      sym_compound_array_assignment,
      sym_compound_function_call,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
  [2665] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(296), 1,
      anon_sym_end,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(300), 1,
      sym_element,
    ACTIONS(302), 1,
      sym_word,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(533), 1,
      sym_input_body,
    STATE(312), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
    STATE(313), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
    STATE(234), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [2718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(304), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(306), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token2,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACE,
  [2749] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
    ACTIONS(308), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(310), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(314), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(316), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(318), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(320), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2833] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(322), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(324), 14,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2862] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(328), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(330), 14,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(334), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(310), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(336), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(338), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2972] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(344), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(340), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(342), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      aux_sym_compound_for_loop_token3,
      aux_sym_compound_for_loop_token4,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [2999] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(346), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(499), 1,
      sym_input_body,
    ACTIONS(348), 2,
      sym_quoted_string,
      sym_float,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [3038] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(350), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(461), 1,
      sym_input_body,
    ACTIONS(352), 2,
      sym_quoted_string,
      sym_float,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [3077] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(354), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(476), 1,
      sym_input_body,
    ACTIONS(356), 2,
      sym_quoted_string,
      sym_float,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [3116] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(358), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(539), 1,
      sym_input_body,
    ACTIONS(360), 2,
      sym_quoted_string,
      sym_float,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [3155] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(362), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(445), 1,
      sym_input_body,
    ACTIONS(364), 2,
      sym_quoted_string,
      sym_float,
    STATE(110), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [3194] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(368), 1,
      anon_sym_SEMI,
    ACTIONS(366), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(370), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3218] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(374), 1,
      aux_sym_compound_step_block_token2,
    ACTIONS(376), 1,
      anon_sym_STAR,
    STATE(54), 1,
      sym_input_title,
    STATE(495), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3250] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(374), 1,
      aux_sym_compound_step_block_token4,
    ACTIONS(376), 1,
      anon_sym_STAR,
    STATE(54), 1,
      sym_input_title,
    STATE(496), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3282] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(380), 1,
      anon_sym_SEMI,
    ACTIONS(378), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3306] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(384), 1,
      aux_sym_compound_step_block_token2,
    STATE(54), 1,
      sym_input_title,
    STATE(455), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3338] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(384), 1,
      aux_sym_compound_step_block_token4,
    STATE(54), 1,
      sym_input_title,
    STATE(456), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3370] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(386), 1,
      aux_sym_compound_step_block_token2,
    STATE(54), 1,
      sym_input_title,
    STATE(515), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3402] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(388), 1,
      anon_sym_BANG,
    ACTIONS(393), 1,
      anon_sym_STAR,
    ACTIONS(396), 1,
      anon_sym_PERCENT,
    STATE(54), 1,
      sym_input_title,
    ACTIONS(391), 2,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
    STATE(65), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3432] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(386), 1,
      aux_sym_compound_step_block_token4,
    STATE(54), 1,
      sym_input_title,
    STATE(527), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3464] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      aux_sym_compound_step_block_token4,
    STATE(54), 1,
      sym_input_title,
    STATE(531), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3496] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      aux_sym_compound_step_block_token2,
    STATE(54), 1,
      sym_input_title,
    STATE(530), 1,
      sym_compound_step_body,
    STATE(69), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3528] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(86), 1,
      anon_sym_PERCENT,
    ACTIONS(372), 1,
      anon_sym_BANG,
    ACTIONS(376), 1,
      anon_sym_STAR,
    STATE(54), 1,
      sym_input_title,
    ACTIONS(401), 2,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
    STATE(65), 8,
      sym_simple_line,
      sym__input,
      sym_input_line,
      sym_input_block,
      sym__geom,
      sym_geom_line,
      sym_geom_block,
      aux_sym_compound_step_body_repeat1,
  [3558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(405), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3579] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(364), 1,
      sym_compound_comparison,
    STATE(382), 1,
      sym_compound_condition,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [3620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      anon_sym_SEMI,
    ACTIONS(366), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(370), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [3643] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 1,
      anon_sym_SEMI,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [3666] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(421), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3687] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(343), 1,
      sym_compound_condition,
    STATE(364), 1,
      sym_compound_comparison,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [3728] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(349), 1,
      sym_compound_condition,
    STATE(364), 1,
      sym_compound_comparison,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [3769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(423), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(425), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(429), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3811] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    ACTIONS(431), 1,
      anon_sym_RPAREN,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(369), 1,
      sym_compound_expression,
    STATE(466), 1,
      sym_compound_argument_list,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [3852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(435), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3894] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(363), 1,
      sym_compound_condition,
    STATE(364), 1,
      sym_compound_comparison,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [3935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(439), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(443), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [3998] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    ACTIONS(449), 1,
      anon_sym_RPAREN,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(369), 1,
      sym_compound_expression,
    STATE(451), 1,
      sym_compound_argument_list,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(453), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(457), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4081] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    ACTIONS(459), 1,
      anon_sym_RPAREN,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(369), 1,
      sym_compound_expression,
    STATE(505), 1,
      sym_compound_argument_list,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(463), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(467), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(471), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4185] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(473), 1,
      anon_sym_EQ,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(477), 1,
      sym_word,
    ACTIONS(481), 1,
      sym_quoted_string,
    STATE(250), 1,
      sym_value_atom,
    STATE(309), 1,
      sym_value,
    ACTIONS(479), 3,
      sym_string,
      sym_float,
      sym_integer,
    STATE(294), 3,
      sym_compound_variable_reference,
      sym_array,
      sym_brace_block,
  [4220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(483), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(485), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(487), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(489), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(493), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(495), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(497), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(501), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4325] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    ACTIONS(503), 1,
      anon_sym_RPAREN,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(369), 1,
      sym_compound_expression,
    STATE(547), 1,
      sym_compound_argument_list,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(507), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(511), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(515), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(519), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(523), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(527), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(531), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4513] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(364), 1,
      sym_compound_comparison,
    STATE(372), 1,
      sym_compound_condition,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4554] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(235), 1,
      sym_compound_expression,
    STATE(364), 1,
      sym_compound_comparison,
    STATE(378), 1,
      sym_compound_condition,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 4,
      ts_builtin_sym_end,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(535), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      aux_sym_compound_script_token2,
      aux_sym_compound_script_token3,
      sym_word,
  [4616] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(302), 1,
      sym_word,
    ACTIONS(537), 1,
      anon_sym_end,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(111), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [4648] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_end,
    ACTIONS(541), 1,
      anon_sym_LBRACE,
    ACTIONS(544), 1,
      sym_word,
    STATE(93), 1,
      sym_input_key,
    STATE(229), 1,
      sym_array,
    STATE(335), 1,
      sym_variable_name,
    STATE(357), 1,
      sym_brace_block,
    STATE(111), 5,
      sym_subblock,
      sym_kv_pair,
      sym_variable_def,
      sym_raw_content,
      aux_sym_input_body_repeat1,
  [4680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(515), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4700] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(593), 1,
      sym_compound_assignment_value,
    STATE(594), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [4738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(523), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4758] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(527), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(531), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(405), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(501), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(547), 1,
      anon_sym_SEMI,
    ACTIONS(366), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(370), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(507), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4900] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(519), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(551), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 1,
      anon_sym_SEMI,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(435), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [4982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(493), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(471), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5022] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(511), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5062] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 1,
      anon_sym_SEMI,
    ACTIONS(366), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(370), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(557), 1,
      anon_sym_SEMI,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(421), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(439), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(443), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5166] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(477), 1,
      sym_word,
    ACTIONS(481), 1,
      sym_quoted_string,
    STATE(250), 1,
      sym_value_atom,
    STATE(315), 1,
      sym_value,
    ACTIONS(479), 3,
      sym_string,
      sym_float,
      sym_integer,
    STATE(294), 3,
      sym_compound_variable_reference,
      sym_array,
      sym_brace_block,
  [5198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(457), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(429), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(453), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5258] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(464), 1,
      sym_compound_assignment_value,
    STATE(594), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5296] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(504), 1,
      sym_compound_assignment_value,
    STATE(594), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5334] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(546), 1,
      sym_compound_assignment_value,
    STATE(594), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(463), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5392] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(467), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(483), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(485), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(535), 9,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token3,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(443), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5471] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(529), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5506] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(551), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5541] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(513), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5576] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(514), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5611] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(525), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [5646] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(551), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(453), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(429), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(435), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(421), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(535), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(439), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(457), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(463), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(467), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(483), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(485), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(551), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5893] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(493), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(515), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(523), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(527), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5969] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(531), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [5988] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(453), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(405), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(501), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(429), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6083] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(435), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(507), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(519), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6140] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(421), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(535), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(382), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(439), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6216] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_LBRACE,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(477), 1,
      sym_word,
    ACTIONS(481), 1,
      sym_quoted_string,
    STATE(288), 1,
      sym_value_atom,
    ACTIONS(479), 3,
      sym_string,
      sym_float,
      sym_integer,
    STATE(294), 3,
      sym_compound_variable_reference,
      sym_array,
      sym_brace_block,
  [6245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(455), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(457), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(463), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(467), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(471), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(483), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(485), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6340] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(493), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(511), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_if_block_token4,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(515), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(523), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(527), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(531), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(405), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(501), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(507), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(519), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(471), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(511), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [6587] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(561), 1,
      anon_sym_RBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(366), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [6616] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(333), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6651] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(440), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6686] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(457), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6721] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(403), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6756] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(467), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6791] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(469), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6826] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(506), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6861] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(508), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6896] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(552), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6931] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(561), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [6966] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(465), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7001] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(479), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7036] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(493), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7071] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(537), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7106] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(47), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(52), 1,
      sym_compound_additive_expr,
    STATE(544), 1,
      sym_compound_expression,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 3,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(443), 8,
      aux_sym_compound_variable_declaration_token1,
      aux_sym_compound_step_block_token1,
      aux_sym_compound_step_block_token3,
      aux_sym_compound_for_loop_token1,
      aux_sym_compound_for_loop_token5,
      aux_sym_compound_if_block_token1,
      aux_sym_compound_array_assignment_token1,
      sym_word,
  [7160] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(431), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [7186] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(468), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [7212] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(569), 1,
      anon_sym_RBRACE,
    STATE(247), 1,
      sym_brace_value,
    STATE(477), 1,
      sym_brace_content,
    STATE(486), 1,
      sym_constraint_content,
    ACTIONS(573), 2,
      sym_float,
      sym_integer,
    ACTIONS(571), 4,
      anon_sym_A,
      anon_sym_B,
      anon_sym_D,
      anon_sym_T,
  [7238] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(507), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [7264] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(481), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [7290] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      sym_quoted_string,
    STATE(556), 1,
      sym_compound_value,
    ACTIONS(563), 2,
      aux_sym_compound_boolean_token1,
      aux_sym_compound_boolean_token2,
    STATE(323), 2,
      sym_compound_boolean,
      sym_compound_array,
    ACTIONS(565), 3,
      sym_word,
      sym_float,
      sym_integer,
  [7316] = 5,
    ACTIONS(575), 1,
      anon_sym_LF,
    ACTIONS(577), 1,
      anon_sym_EQ,
    ACTIONS(580), 1,
      anon_sym_LBRACK,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(583), 7,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_word,
      sym_string,
      sym_quoted_string,
      sym_float,
      sym_integer,
  [7338] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(589), 1,
      anon_sym_RBRACE,
    ACTIONS(593), 2,
      sym_float,
      sym_integer,
    STATE(227), 2,
      sym_compound_variable_reference,
      aux_sym_constraint_content_repeat1,
    ACTIONS(591), 3,
      anon_sym_C,
      anon_sym_S,
      anon_sym_F,
  [7361] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(45), 1,
      sym_compound_primary_expr,
    STATE(48), 1,
      sym_compound_multiplicative_expr,
    STATE(50), 1,
      sym_compound_array_access,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7390] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(595), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(600), 2,
      sym_float,
      sym_integer,
    STATE(227), 2,
      sym_compound_variable_reference,
      aux_sym_constraint_content_repeat1,
    ACTIONS(598), 4,
      anon_sym_RBRACE,
      anon_sym_C,
      anon_sym_S,
      anon_sym_F,
  [7411] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(605), 1,
      sym_element,
    ACTIONS(603), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 4,
      sym_word,
      sym_string,
      sym_float,
      sym_integer,
    ACTIONS(608), 4,
      anon_sym_EQ,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_quoted_string,
  [7445] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 1,
      anon_sym_LPAREN,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      sym_quoted_string,
    STATE(44), 1,
      sym_variable_name,
    STATE(50), 1,
      sym_compound_array_access,
    STATE(51), 1,
      sym_compound_primary_expr,
    ACTIONS(413), 2,
      sym_float,
      sym_integer,
  [7471] = 8,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(610), 1,
      anon_sym_LF,
    ACTIONS(612), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(614), 1,
      anon_sym_LBRACE,
    ACTIONS(616), 1,
      sym_float,
    ACTIONS(618), 1,
      sym_integer,
    STATE(245), 1,
      sym_coord_value,
    STATE(385), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [7497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(620), 4,
      anon_sym_EQ,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_quoted_string,
    ACTIONS(622), 4,
      sym_word,
      sym_string,
      sym_float,
      sym_integer,
  [7513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(624), 1,
      anon_sym_STAR,
    ACTIONS(626), 1,
      sym_element,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7530] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 1,
      anon_sym_end,
    ACTIONS(630), 1,
      sym_element,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(632), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(634), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(636), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(638), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_integer,
  [7577] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(640), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(644), 1,
      sym_float,
    ACTIONS(646), 1,
      sym_integer,
    STATE(405), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [7600] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    ACTIONS(648), 1,
      anon_sym_STAR,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7617] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    ACTIONS(650), 1,
      anon_sym_STAR,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7634] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    ACTIONS(652), 1,
      anon_sym_STAR,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    ACTIONS(654), 1,
      anon_sym_STAR,
    STATE(228), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [7668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(636), 2,
      sym_float,
      sym_integer,
    ACTIONS(638), 5,
      anon_sym_AMP_LBRACE,
      anon_sym_RBRACE,
      anon_sym_C,
      anon_sym_S,
      anon_sym_F,
  [7683] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(656), 1,
      anon_sym_COMMA,
    ACTIONS(658), 1,
      anon_sym_RBRACE,
    ACTIONS(573), 2,
      sym_float,
      sym_integer,
    STATE(272), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [7701] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 1,
      anon_sym_xyz,
    ACTIONS(662), 1,
      anon_sym_int,
    ACTIONS(664), 1,
      anon_sym_gzmt,
    STATE(322), 1,
      sym_geom_line_types,
    ACTIONS(666), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [7721] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(670), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      sym_float,
    STATE(262), 1,
      sym_coord_value,
    STATE(385), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [7741] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(670), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      sym_float,
    STATE(245), 1,
      sym_coord_value,
    STATE(385), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [7761] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(656), 1,
      anon_sym_COMMA,
    ACTIONS(674), 1,
      anon_sym_RBRACE,
    ACTIONS(573), 2,
      sym_float,
      sym_integer,
    STATE(243), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [7779] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(676), 1,
      anon_sym_xyz,
    ACTIONS(678), 1,
      anon_sym_int,
    ACTIONS(680), 1,
      anon_sym_gzmt,
    STATE(398), 1,
      sym_geom_line_types,
    ACTIONS(666), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [7799] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(682), 1,
      anon_sym_LF,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(251), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7819] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    STATE(255), 1,
      aux_sym_value_repeat1,
    ACTIONS(688), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(690), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [7837] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(694), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7857] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(696), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(253), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7877] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(698), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7897] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(704), 1,
      anon_sym_COMMA,
    STATE(254), 1,
      aux_sym_value_repeat1,
    ACTIONS(700), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(702), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [7915] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    STATE(254), 1,
      aux_sym_value_repeat1,
    ACTIONS(707), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(709), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [7933] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(711), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(257), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7953] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(713), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7973] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(715), 1,
      anon_sym_LF,
    ACTIONS(717), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(720), 1,
      aux_sym_arg_token1,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [7993] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(723), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(264), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [8013] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(725), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [8033] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    STATE(238), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [8047] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(729), 1,
      sym_float,
    STATE(497), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8067] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(640), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(729), 1,
      sym_float,
    STATE(405), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8087] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(731), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(258), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [8107] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(670), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      sym_float,
    STATE(267), 1,
      sym_coord_value,
    STATE(385), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8127] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(640), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(729), 1,
      sym_float,
    STATE(419), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8147] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(670), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      sym_float,
    STATE(276), 1,
      sym_coord_value,
    STATE(385), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    STATE(239), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [8181] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(737), 1,
      anon_sym_LBRACK,
    ACTIONS(733), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(735), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    STATE(233), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [8211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    STATE(240), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [8225] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 1,
      anon_sym_COMMA,
    ACTIONS(742), 1,
      anon_sym_RBRACE,
    ACTIONS(744), 2,
      sym_float,
      sym_integer,
    STATE(272), 2,
      sym_brace_value,
      aux_sym_brace_content_repeat1,
  [8243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 1,
      sym_element,
    STATE(241), 5,
      sym_zmat_line1,
      sym_zmat_line2,
      sym_zmat_line3,
      sym_zmat_line4,
      aux_sym_subblock_repeat3,
  [8257] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      anon_sym_xyz,
    ACTIONS(749), 1,
      anon_sym_int,
    ACTIONS(751), 1,
      anon_sym_gzmt,
    STATE(392), 1,
      sym_geom_line_types,
    ACTIONS(666), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [8277] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 1,
      anon_sym_xyz,
    ACTIONS(755), 1,
      anon_sym_int,
    ACTIONS(757), 1,
      anon_sym_gzmt,
    STATE(394), 1,
      sym_geom_line_types,
    ACTIONS(666), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [8297] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(729), 1,
      sym_float,
    STATE(463), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8317] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 1,
      anon_sym_xyz,
    ACTIONS(761), 1,
      anon_sym_int,
    ACTIONS(763), 1,
      anon_sym_gzmt,
    STATE(397), 1,
      sym_geom_line_types,
    ACTIONS(666), 2,
      anon_sym_xyzfile,
      anon_sym_gzmtfile,
  [8337] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(642), 1,
      anon_sym_LBRACE,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(729), 1,
      sym_float,
    STATE(474), 1,
      sym_coord_value,
    STATE(409), 2,
      sym_compound_variable_reference,
      sym_variable_ref,
  [8357] = 6,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(684), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(686), 1,
      aux_sym_arg_token1,
    ACTIONS(765), 1,
      anon_sym_LF,
    STATE(376), 1,
      sym_compound_variable_reference,
    STATE(260), 2,
      sym_arg,
      aux_sym_simple_line_repeat1,
  [8377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8388] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(622), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(620), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8401] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(769), 1,
      sym_element,
    ACTIONS(767), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8416] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(774), 1,
      sym_element,
    ACTIONS(772), 2,
      anon_sym_end,
      anon_sym_STAR,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8431] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8442] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(777), 1,
      anon_sym_EQ,
    ACTIONS(779), 1,
      anon_sym_SEMI,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(783), 1,
      anon_sym_LBRACK,
    STATE(328), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [8461] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(785), 1,
      anon_sym_EQ,
    ACTIONS(787), 1,
      anon_sym_SEMI,
    ACTIONS(789), 1,
      anon_sym_LBRACK,
    STATE(329), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [8480] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_SEMI,
    ACTIONS(795), 1,
      anon_sym_COMMA,
    ACTIONS(797), 1,
      anon_sym_LBRACE,
    ACTIONS(791), 2,
      anon_sym_end,
      sym_word,
  [8497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(700), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(702), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8510] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(799), 2,
      sym_float,
      sym_integer,
    STATE(225), 2,
      sym_compound_variable_reference,
      aux_sym_constraint_content_repeat1,
  [8525] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(801), 1,
      anon_sym_EQ,
    ACTIONS(803), 1,
      anon_sym_SEMI,
    ACTIONS(805), 1,
      anon_sym_LBRACK,
    STATE(400), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [8544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(809), 3,
      anon_sym_LBRACE,
      sym_quoted_string,
      sym_float,
  [8568] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(811), 1,
      anon_sym_EQ,
    ACTIONS(813), 1,
      anon_sym_SEMI,
    ACTIONS(815), 1,
      anon_sym_LBRACK,
    STATE(337), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [8587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(735), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(817), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(819), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(823), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [8648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 5,
      anon_sym_BANG,
      aux_sym_compound_step_block_token2,
      aux_sym_compound_step_block_token4,
      anon_sym_STAR,
      anon_sym_PERCENT,
  [8670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_SEMI,
    ACTIONS(797), 1,
      anon_sym_LBRACE,
    ACTIONS(791), 2,
      anon_sym_end,
      sym_word,
  [8684] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(654), 1,
      anon_sym_STAR,
    ACTIONS(825), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(654), 1,
      anon_sym_STAR,
    ACTIONS(827), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8712] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(624), 1,
      anon_sym_STAR,
    ACTIONS(825), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8726] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(624), 1,
      anon_sym_STAR,
    ACTIONS(827), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(829), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(831), 2,
      sym_float,
      sym_integer,
  [8752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(648), 1,
      anon_sym_STAR,
    ACTIONS(825), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(833), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(835), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [8778] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(839), 1,
      anon_sym_SEMI,
    ACTIONS(841), 1,
      anon_sym_LBRACE,
    ACTIONS(837), 2,
      anon_sym_end,
      sym_word,
  [8792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(843), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(845), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [8804] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(648), 1,
      anon_sym_STAR,
    ACTIONS(827), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 1,
      anon_sym_end,
    ACTIONS(847), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8832] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 1,
      anon_sym_end,
    ACTIONS(849), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 2,
      anon_sym_end,
      sym_word,
    ACTIONS(853), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [8858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(857), 1,
      anon_sym_SEMI,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(855), 2,
      anon_sym_end,
      sym_word,
  [8872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(742), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(861), 2,
      sym_float,
      sym_integer,
  [8884] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(865), 1,
      anon_sym_SEMI,
    ACTIONS(867), 1,
      anon_sym_LBRACE,
    ACTIONS(863), 2,
      anon_sym_end,
      sym_word,
  [8898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(650), 1,
      anon_sym_STAR,
    ACTIONS(825), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(652), 1,
      anon_sym_STAR,
    ACTIONS(825), 1,
      sym_element,
    STATE(282), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [8926] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(652), 1,
      anon_sym_STAR,
    ACTIONS(827), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(650), 1,
      anon_sym_STAR,
    ACTIONS(827), 1,
      sym_element,
    STATE(283), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [8954] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(869), 1,
      sym_integer,
    STATE(387), 1,
      sym_compound_variable_reference,
  [8967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(871), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [8976] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(873), 1,
      anon_sym_SEMI,
    ACTIONS(875), 1,
      anon_sym_COMMA,
    STATE(324), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [8989] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(878), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [8998] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      sym_float,
    ACTIONS(882), 1,
      sym_integer,
    STATE(301), 1,
      sym_variable_range,
  [9011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(884), 1,
      sym_file,
    STATE(523), 1,
      sym_compound_variable_reference,
  [9024] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_SEMI,
    STATE(324), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [9037] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(888), 1,
      anon_sym_SEMI,
    STATE(324), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [9050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_LBRACE,
    ACTIONS(791), 2,
      anon_sym_end,
      sym_word,
  [9061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(890), 2,
      anon_sym_end,
      sym_word,
  [9072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(894), 3,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_float,
  [9081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(896), 3,
      anon_sym_RPAREN,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
  [9090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(900), 1,
      sym_element,
    ACTIONS(898), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9101] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(902), 1,
      anon_sym_EQ,
    ACTIONS(904), 1,
      anon_sym_LBRACK,
    STATE(317), 1,
      sym_variable_array,
  [9114] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
    ACTIONS(906), 1,
      anon_sym_EQ,
    ACTIONS(908), 1,
      anon_sym_LPAREN,
  [9127] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(910), 1,
      anon_sym_SEMI,
    STATE(324), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [9140] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(914), 1,
      sym_integer,
    STATE(327), 1,
      sym_compound_variable_reference,
  [9153] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(916), 1,
      anon_sym_RBRACK,
    ACTIONS(918), 1,
      sym_float,
    STATE(353), 1,
      aux_sym_variable_array_repeat1,
  [9166] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(920), 1,
      anon_sym_COMMA,
    ACTIONS(922), 1,
      anon_sym_RPAREN,
    STATE(359), 1,
      aux_sym_compound_argument_list_repeat1,
  [9179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(926), 1,
      sym_element,
    ACTIONS(924), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(928), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [9199] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(930), 3,
      anon_sym_RPAREN,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
  [9208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(316), 1,
      sym_brace_value,
    ACTIONS(573), 2,
      sym_float,
      sym_integer,
  [9219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(452), 1,
      sym_variable_name,
    STATE(484), 1,
      sym_compound_array_access,
  [9232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
    ACTIONS(932), 1,
      anon_sym_EQ,
    ACTIONS(934), 1,
      anon_sym_LPAREN,
  [9245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(938), 1,
      anon_sym_LBRACE,
    ACTIONS(936), 2,
      anon_sym_end,
      sym_word,
  [9256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(942), 1,
      sym_element,
    ACTIONS(940), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_compound_condition_token1,
    ACTIONS(930), 2,
      anon_sym_RPAREN,
      aux_sym_compound_condition_token2,
  [9278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(948), 1,
      sym_element,
    ACTIONS(946), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9289] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(950), 1,
      sym_file,
    STATE(472), 1,
      sym_compound_variable_reference,
  [9302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(954), 1,
      sym_element,
    ACTIONS(952), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(956), 1,
      anon_sym_RBRACK,
    ACTIONS(958), 1,
      sym_float,
    STATE(395), 1,
      aux_sym_variable_array_repeat1,
  [9326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(962), 1,
      anon_sym_LBRACE,
    ACTIONS(960), 2,
      anon_sym_end,
      sym_word,
  [9337] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
    ACTIONS(964), 1,
      anon_sym_EQ,
    ACTIONS(966), 1,
      anon_sym_LPAREN,
  [9350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(970), 1,
      anon_sym_LBRACE,
    ACTIONS(968), 2,
      anon_sym_end,
      sym_word,
  [9361] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(974), 1,
      anon_sym_LBRACE,
    ACTIONS(972), 2,
      anon_sym_end,
      sym_word,
  [9372] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(976), 1,
      sym_file,
    STATE(512), 1,
      sym_compound_variable_reference,
  [9385] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_COMMA,
    ACTIONS(981), 1,
      anon_sym_RPAREN,
    STATE(359), 1,
      aux_sym_compound_argument_list_repeat1,
  [9398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(983), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [9407] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    ACTIONS(987), 1,
      anon_sym_RBRACK,
    STATE(402), 1,
      aux_sym_compound_array_repeat1,
  [9420] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_EQ,
    ACTIONS(991), 1,
      anon_sym_LPAREN,
  [9433] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_compound_condition_token1,
    ACTIONS(993), 1,
      anon_sym_RPAREN,
    ACTIONS(995), 1,
      aux_sym_compound_condition_token2,
  [9446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(997), 3,
      anon_sym_RPAREN,
      aux_sym_compound_condition_token1,
      aux_sym_compound_condition_token2,
  [9455] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(999), 1,
      sym_file,
    STATE(567), 1,
      sym_compound_variable_reference,
  [9468] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    ACTIONS(1001), 1,
      anon_sym_RBRACK,
    STATE(361), 1,
      aux_sym_compound_array_repeat1,
  [9481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      sym_element,
    STATE(307), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [9492] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1003), 1,
      sym_file,
    STATE(447), 1,
      sym_compound_variable_reference,
  [9505] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(920), 1,
      anon_sym_COMMA,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    STATE(340), 1,
      aux_sym_compound_argument_list_repeat1,
  [9518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym_element,
    STATE(311), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [9529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1007), 1,
      sym_integer,
    STATE(351), 1,
      sym_compound_variable_reference,
  [9542] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_compound_condition_token1,
    ACTIONS(995), 1,
      aux_sym_compound_condition_token2,
    ACTIONS(1009), 1,
      anon_sym_RPAREN,
  [9555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      sym_element,
    STATE(318), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [9566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym_element,
    STATE(321), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [9577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      sym_element,
    ACTIONS(1011), 2,
      anon_sym_end,
      anon_sym_STAR,
  [9588] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1015), 1,
      anon_sym_LF,
    ACTIONS(1017), 2,
      anon_sym_AMP_LBRACE,
      aux_sym_arg_token1,
  [9599] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1019), 1,
      sym_integer,
    STATE(358), 1,
      sym_compound_variable_reference,
  [9612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_compound_condition_token1,
    ACTIONS(995), 1,
      aux_sym_compound_condition_token2,
    ACTIONS(1021), 1,
      anon_sym_RPAREN,
  [9625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      sym_element,
    STATE(304), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [9636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym_element,
    STATE(305), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [9647] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1023), 1,
      sym_integer,
    STATE(365), 1,
      sym_compound_variable_reference,
  [9660] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_compound_condition_token1,
    ACTIONS(995), 1,
      aux_sym_compound_condition_token2,
    ACTIONS(1025), 1,
      anon_sym_RPAREN,
  [9673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      sym_element,
    STATE(319), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [9684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym_element,
    STATE(320), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [9695] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1027), 3,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_float,
  [9704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(638), 3,
      anon_sym_AMP_LBRACE,
      anon_sym_LBRACE,
      sym_float,
  [9713] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1029), 1,
      sym_integer,
    STATE(368), 1,
      sym_compound_variable_reference,
  [9726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      sym_element,
    STATE(302), 2,
      sym_xyz_line,
      aux_sym_subblock_repeat1,
  [9737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym_element,
    STATE(303), 2,
      sym_int_line,
      aux_sym_subblock_repeat2,
  [9748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(855), 2,
      anon_sym_end,
      sym_word,
  [9759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(452), 1,
      sym_variable_name,
    STATE(501), 1,
      sym_compound_array_access,
  [9772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1031), 1,
      sym_integer,
    STATE(371), 1,
      sym_compound_variable_reference,
  [9785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(452), 1,
      sym_variable_name,
    STATE(510), 1,
      sym_compound_array_access,
  [9798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1033), 1,
      sym_integer,
    STATE(377), 1,
      sym_compound_variable_reference,
  [9811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1035), 1,
      anon_sym_RBRACK,
    ACTIONS(1037), 1,
      sym_float,
    STATE(395), 1,
      aux_sym_variable_array_repeat1,
  [9824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(452), 1,
      sym_variable_name,
    STATE(519), 1,
      sym_compound_array_access,
  [9837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1040), 1,
      sym_integer,
    STATE(381), 1,
      sym_compound_variable_reference,
  [9850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_AMP_LBRACE,
    ACTIONS(1042), 1,
      sym_integer,
    STATE(338), 1,
      sym_compound_variable_reference,
  [9863] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(638), 1,
      anon_sym_LF,
    ACTIONS(636), 2,
      anon_sym_AMP_LBRACE,
      aux_sym_arg_token1,
  [9874] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(1044), 1,
      anon_sym_SEMI,
    STATE(324), 1,
      aux_sym_compound_variable_declaration_repeat1,
  [9887] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1046), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [9896] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1048), 1,
      anon_sym_COMMA,
    ACTIONS(1051), 1,
      anon_sym_RBRACK,
    STATE(402), 1,
      aux_sym_compound_array_repeat1,
  [9909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(981), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [9917] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(462), 1,
      sym_variable_name,
  [9927] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_LF,
    ACTIONS(1055), 1,
      sym_integer,
  [9937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(450), 1,
      sym_variable_name,
  [9947] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 2,
      sym_float,
      sym_integer,
  [9955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(524), 1,
      sym_variable_name,
  [9965] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1027), 1,
      anon_sym_LF,
    ACTIONS(1059), 1,
      sym_integer,
  [9975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(285), 1,
      sym_variable_name,
  [9985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(873), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [9993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(502), 1,
      sym_variable_name,
  [10003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(528), 1,
      sym_variable_name,
  [10013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(446), 1,
      sym_variable_name,
  [10023] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(286), 1,
      sym_variable_name,
  [10033] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 2,
      sym_float,
      sym_integer,
  [10041] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(894), 1,
      anon_sym_LF,
    ACTIONS(1063), 1,
      sym_integer,
  [10051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(540), 1,
      sym_variable_name,
  [10061] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1065), 1,
      anon_sym_LF,
    ACTIONS(1067), 1,
      sym_integer,
  [10071] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 2,
      sym_float,
      sym_integer,
  [10079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1071), 1,
      aux_sym_compound_script_token1,
    ACTIONS(1073), 1,
      sym_word,
  [10089] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(411), 1,
      sym_variable_name,
  [10099] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 2,
      sym_string,
      sym_integer,
  [10107] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(610), 1,
      anon_sym_LF,
    ACTIONS(1077), 1,
      sym_integer,
  [10117] = 3,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(636), 1,
      sym_integer,
    ACTIONS(638), 1,
      anon_sym_LF,
  [10127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(589), 1,
      sym_variable_name,
  [10137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1079), 2,
      anon_sym_AMP_LBRACE,
      sym_integer,
  [10145] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1081), 2,
      sym_string,
      sym_integer,
  [10153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(478), 1,
      sym_variable_name,
  [10163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(638), 2,
      anon_sym_AMP_LBRACE,
      sym_file,
  [10171] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1051), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [10179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(293), 1,
      sym_variable_name,
  [10189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1083), 2,
      sym_float,
      sym_integer,
  [10197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(290), 1,
      sym_variable_name,
  [10207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(581), 1,
      sym_variable_name,
  [10217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(585), 1,
      sym_variable_name,
  [10227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    STATE(449), 1,
      sym_variable_name,
  [10237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      sym_integer,
  [10244] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1087), 1,
      anon_sym_LF,
  [10251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_RBRACK,
  [10258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      sym_float,
  [10265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1093), 1,
      sym_integer,
  [10272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1095), 1,
      sym_integer,
  [10279] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1097), 1,
      anon_sym_LF,
  [10286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1099), 1,
      anon_sym_end,
  [10293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1101), 1,
      anon_sym_RBRACE,
  [10300] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1103), 1,
      anon_sym_LF,
  [10307] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1105), 1,
      anon_sym_LF,
  [10314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1107), 1,
      anon_sym_RBRACE,
  [10321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1109), 1,
      anon_sym_RBRACE,
  [10328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_RPAREN,
  [10335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_LBRACK,
  [10342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1113), 1,
      sym_integer,
  [10349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1115), 1,
      anon_sym_LPAREN,
  [10356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1117), 1,
      aux_sym_compound_step_block_token2,
  [10363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1117), 1,
      aux_sym_compound_step_block_token4,
  [10370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1119), 1,
      anon_sym_SEMI,
  [10377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1121), 1,
      anon_sym_RBRACK,
  [10384] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LF,
  [10391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1125), 1,
      aux_sym_compound_if_block_token2,
  [10398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1127), 1,
      anon_sym_end,
  [10405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1129), 1,
      anon_sym_RBRACE,
  [10412] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1131), 1,
      anon_sym_LF,
  [10419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_SEMI,
  [10426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1135), 1,
      aux_sym_compound_for_loop_token4,
  [10433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1137), 1,
      anon_sym_RPAREN,
  [10440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1139), 1,
      anon_sym_SEMI,
  [10447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 1,
      anon_sym_SEMI,
  [10454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1143), 1,
      anon_sym_SEMI,
  [10461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1145), 1,
      anon_sym_RBRACK,
  [10468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1147), 1,
      anon_sym_SEMI,
  [10475] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1149), 1,
      anon_sym_LF,
  [10482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1151), 1,
      anon_sym_RBRACK,
  [10489] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1153), 1,
      anon_sym_LF,
  [10496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1155), 1,
      aux_sym_compound_if_block_token2,
  [10503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 1,
      anon_sym_end,
  [10510] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1159), 1,
      anon_sym_RBRACE,
  [10517] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1161), 1,
      anon_sym_RBRACE,
  [10524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1163), 1,
      aux_sym_compound_for_loop_token4,
  [10531] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1165), 1,
      anon_sym_LF,
  [10538] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1167), 1,
      anon_sym_SEMI,
  [10545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1169), 1,
      sym_integer,
  [10552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1171), 1,
      anon_sym_RBRACK,
  [10559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1173), 1,
      anon_sym_EQ,
  [10566] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1175), 1,
      anon_sym_LF,
  [10573] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(674), 1,
      anon_sym_RBRACE,
  [10580] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 1,
      anon_sym_RBRACK,
  [10587] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1179), 1,
      anon_sym_LF,
  [10594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1181), 1,
      aux_sym_compound_if_block_token2,
  [10601] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1183), 1,
      anon_sym_LF,
  [10608] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1185), 1,
      anon_sym_LF,
  [10615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1187), 1,
      sym_word,
  [10622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1189), 1,
      aux_sym_compound_for_loop_token4,
  [10629] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      anon_sym_COMMA,
  [10636] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      aux_sym_compound_step_block_token2,
  [10643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      aux_sym_compound_step_block_token4,
  [10650] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1195), 1,
      anon_sym_LF,
  [10657] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1197), 1,
      anon_sym_LF,
  [10664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1199), 1,
      anon_sym_end,
  [10671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1201), 1,
      anon_sym_EQ,
  [10678] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1203), 1,
      anon_sym_EQ,
  [10685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1205), 1,
      anon_sym_RBRACE,
  [10692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1207), 1,
      sym_float,
  [10699] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1209), 1,
      anon_sym_SEMI,
  [10706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1211), 1,
      anon_sym_RPAREN,
  [10713] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_SEMI,
  [10720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1215), 1,
      anon_sym_SEMI,
  [10727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1217), 1,
      anon_sym_SEMI,
  [10734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1219), 1,
      anon_sym_EQ,
  [10741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1221), 1,
      anon_sym_EQ,
  [10748] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1223), 1,
      anon_sym_SEMI,
  [10755] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1225), 1,
      anon_sym_LF,
  [10762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1227), 1,
      aux_sym_compound_for_loop_token3,
  [10769] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1229), 1,
      anon_sym_RPAREN,
  [10776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1231), 1,
      aux_sym_compound_step_block_token2,
  [10783] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1233), 1,
      anon_sym_LF,
  [10790] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1235), 1,
      sym_integer,
  [10797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 1,
      anon_sym_EQ,
  [10804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1239), 1,
      anon_sym_EQ,
  [10811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1241), 1,
      sym_integer,
  [10818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1243), 1,
      aux_sym_compound_if_block_token2,
  [10825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1245), 1,
      anon_sym_RBRACK,
  [10832] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1247), 1,
      anon_sym_LF,
  [10839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1249), 1,
      aux_sym_compound_for_loop_token2,
  [10846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_SEMI,
  [10853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1253), 1,
      ts_builtin_sym_end,
  [10860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1231), 1,
      aux_sym_compound_step_block_token4,
  [10867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1255), 1,
      anon_sym_RBRACE,
  [10874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1257), 1,
      aux_sym_compound_for_loop_token4,
  [10881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1259), 1,
      aux_sym_compound_step_block_token2,
  [10888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1259), 1,
      aux_sym_compound_step_block_token4,
  [10895] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1261), 1,
      anon_sym_RBRACE,
  [10902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 1,
      anon_sym_end,
  [10909] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1263), 1,
      anon_sym_LF,
  [10916] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1265), 1,
      anon_sym_LF,
  [10923] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1267), 1,
      anon_sym_LF,
  [10930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1269), 1,
      aux_sym_compound_for_loop_token3,
  [10937] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1271), 1,
      anon_sym_LF,
  [10944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1273), 1,
      anon_sym_end,
  [10951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1275), 1,
      anon_sym_RBRACE,
  [10958] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1277), 1,
      anon_sym_LF,
  [10965] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1279), 1,
      anon_sym_LF,
  [10972] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1281), 1,
      anon_sym_LF,
  [10979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1283), 1,
      aux_sym_compound_for_loop_token3,
  [10986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1285), 1,
      sym_integer,
  [10993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1287), 1,
      anon_sym_SEMI,
  [11000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1289), 1,
      anon_sym_RPAREN,
  [11007] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1291), 1,
      anon_sym_LF,
  [11014] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1293), 1,
      anon_sym_LF,
  [11021] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1295), 1,
      anon_sym_LF,
  [11028] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1297), 1,
      aux_sym_compound_for_loop_token3,
  [11035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1299), 1,
      anon_sym_SEMI,
  [11042] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1301), 1,
      anon_sym_LF,
  [11049] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_LF,
  [11056] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1305), 1,
      anon_sym_LF,
  [11063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1307), 1,
      anon_sym_SEMI,
  [11070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1309), 1,
      anon_sym_LPAREN,
  [11077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1311), 1,
      sym_integer,
  [11084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1313), 1,
      sym_integer,
  [11091] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1315), 1,
      sym_integer,
  [11098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1317), 1,
      anon_sym_SEMI,
  [11105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1319), 1,
      anon_sym_SEMI,
  [11112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
  [11119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1323), 1,
      sym_integer,
  [11126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1325), 1,
      sym_integer,
  [11133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1327), 1,
      sym_integer,
  [11140] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1329), 1,
      anon_sym_LF,
  [11147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1331), 1,
      sym_float,
  [11154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1333), 1,
      anon_sym_LPAREN,
  [11161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1335), 1,
      sym_integer,
  [11168] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      sym_integer,
  [11175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1339), 1,
      sym_integer,
  [11182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_EQ,
  [11189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1343), 1,
      sym_integer,
  [11196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      sym_integer,
  [11203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1347), 1,
      sym_integer,
  [11210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 1,
      sym_integer,
  [11217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1351), 1,
      sym_integer,
  [11224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 1,
      sym_integer,
  [11231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1355), 1,
      sym_integer,
  [11238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 1,
      aux_sym_compound_for_loop_token2,
  [11245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1359), 1,
      sym_integer,
  [11252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      sym_integer,
  [11259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1363), 1,
      sym_integer,
  [11266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 1,
      aux_sym_compound_for_loop_token2,
  [11273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1367), 1,
      sym_integer,
  [11280] = 2,
    ACTIONS(585), 1,
      sym_comment,
    ACTIONS(1369), 1,
      anon_sym_LF,
  [11287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1371), 1,
      sym_integer,
  [11294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 1,
      aux_sym_compound_for_loop_token2,
  [11301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1375), 1,
      sym_integer,
  [11308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      sym_integer,
  [11315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1379), 1,
      sym_integer,
  [11322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_SEMI,
  [11329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1383), 1,
      anon_sym_SEMI,
  [11336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      anon_sym_SEMI,
  [11343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1387), 1,
      sym_integer,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 69,
  [SMALL_STATE(4)] = 138,
  [SMALL_STATE(5)] = 207,
  [SMALL_STATE(6)] = 276,
  [SMALL_STATE(7)] = 343,
  [SMALL_STATE(8)] = 412,
  [SMALL_STATE(9)] = 481,
  [SMALL_STATE(10)] = 550,
  [SMALL_STATE(11)] = 619,
  [SMALL_STATE(12)] = 688,
  [SMALL_STATE(13)] = 757,
  [SMALL_STATE(14)] = 823,
  [SMALL_STATE(15)] = 887,
  [SMALL_STATE(16)] = 953,
  [SMALL_STATE(17)] = 1017,
  [SMALL_STATE(18)] = 1083,
  [SMALL_STATE(19)] = 1147,
  [SMALL_STATE(20)] = 1213,
  [SMALL_STATE(21)] = 1279,
  [SMALL_STATE(22)] = 1345,
  [SMALL_STATE(23)] = 1411,
  [SMALL_STATE(24)] = 1477,
  [SMALL_STATE(25)] = 1543,
  [SMALL_STATE(26)] = 1609,
  [SMALL_STATE(27)] = 1675,
  [SMALL_STATE(28)] = 1741,
  [SMALL_STATE(29)] = 1807,
  [SMALL_STATE(30)] = 1873,
  [SMALL_STATE(31)] = 1939,
  [SMALL_STATE(32)] = 2005,
  [SMALL_STATE(33)] = 2071,
  [SMALL_STATE(34)] = 2137,
  [SMALL_STATE(35)] = 2203,
  [SMALL_STATE(36)] = 2269,
  [SMALL_STATE(37)] = 2335,
  [SMALL_STATE(38)] = 2401,
  [SMALL_STATE(39)] = 2467,
  [SMALL_STATE(40)] = 2533,
  [SMALL_STATE(41)] = 2599,
  [SMALL_STATE(42)] = 2665,
  [SMALL_STATE(43)] = 2718,
  [SMALL_STATE(44)] = 2749,
  [SMALL_STATE(45)] = 2779,
  [SMALL_STATE(46)] = 2806,
  [SMALL_STATE(47)] = 2833,
  [SMALL_STATE(48)] = 2862,
  [SMALL_STATE(49)] = 2891,
  [SMALL_STATE(50)] = 2918,
  [SMALL_STATE(51)] = 2945,
  [SMALL_STATE(52)] = 2972,
  [SMALL_STATE(53)] = 2999,
  [SMALL_STATE(54)] = 3038,
  [SMALL_STATE(55)] = 3077,
  [SMALL_STATE(56)] = 3116,
  [SMALL_STATE(57)] = 3155,
  [SMALL_STATE(58)] = 3194,
  [SMALL_STATE(59)] = 3218,
  [SMALL_STATE(60)] = 3250,
  [SMALL_STATE(61)] = 3282,
  [SMALL_STATE(62)] = 3306,
  [SMALL_STATE(63)] = 3338,
  [SMALL_STATE(64)] = 3370,
  [SMALL_STATE(65)] = 3402,
  [SMALL_STATE(66)] = 3432,
  [SMALL_STATE(67)] = 3464,
  [SMALL_STATE(68)] = 3496,
  [SMALL_STATE(69)] = 3528,
  [SMALL_STATE(70)] = 3558,
  [SMALL_STATE(71)] = 3579,
  [SMALL_STATE(72)] = 3620,
  [SMALL_STATE(73)] = 3643,
  [SMALL_STATE(74)] = 3666,
  [SMALL_STATE(75)] = 3687,
  [SMALL_STATE(76)] = 3728,
  [SMALL_STATE(77)] = 3769,
  [SMALL_STATE(78)] = 3790,
  [SMALL_STATE(79)] = 3811,
  [SMALL_STATE(80)] = 3852,
  [SMALL_STATE(81)] = 3873,
  [SMALL_STATE(82)] = 3894,
  [SMALL_STATE(83)] = 3935,
  [SMALL_STATE(84)] = 3956,
  [SMALL_STATE(85)] = 3977,
  [SMALL_STATE(86)] = 3998,
  [SMALL_STATE(87)] = 4039,
  [SMALL_STATE(88)] = 4060,
  [SMALL_STATE(89)] = 4081,
  [SMALL_STATE(90)] = 4122,
  [SMALL_STATE(91)] = 4143,
  [SMALL_STATE(92)] = 4164,
  [SMALL_STATE(93)] = 4185,
  [SMALL_STATE(94)] = 4220,
  [SMALL_STATE(95)] = 4241,
  [SMALL_STATE(96)] = 4262,
  [SMALL_STATE(97)] = 4283,
  [SMALL_STATE(98)] = 4304,
  [SMALL_STATE(99)] = 4325,
  [SMALL_STATE(100)] = 4366,
  [SMALL_STATE(101)] = 4387,
  [SMALL_STATE(102)] = 4408,
  [SMALL_STATE(103)] = 4429,
  [SMALL_STATE(104)] = 4450,
  [SMALL_STATE(105)] = 4471,
  [SMALL_STATE(106)] = 4492,
  [SMALL_STATE(107)] = 4513,
  [SMALL_STATE(108)] = 4554,
  [SMALL_STATE(109)] = 4595,
  [SMALL_STATE(110)] = 4616,
  [SMALL_STATE(111)] = 4648,
  [SMALL_STATE(112)] = 4680,
  [SMALL_STATE(113)] = 4700,
  [SMALL_STATE(114)] = 4738,
  [SMALL_STATE(115)] = 4758,
  [SMALL_STATE(116)] = 4778,
  [SMALL_STATE(117)] = 4798,
  [SMALL_STATE(118)] = 4818,
  [SMALL_STATE(119)] = 4838,
  [SMALL_STATE(120)] = 4858,
  [SMALL_STATE(121)] = 4880,
  [SMALL_STATE(122)] = 4900,
  [SMALL_STATE(123)] = 4920,
  [SMALL_STATE(124)] = 4940,
  [SMALL_STATE(125)] = 4962,
  [SMALL_STATE(126)] = 4982,
  [SMALL_STATE(127)] = 5002,
  [SMALL_STATE(128)] = 5022,
  [SMALL_STATE(129)] = 5042,
  [SMALL_STATE(130)] = 5062,
  [SMALL_STATE(131)] = 5084,
  [SMALL_STATE(132)] = 5106,
  [SMALL_STATE(133)] = 5126,
  [SMALL_STATE(134)] = 5146,
  [SMALL_STATE(135)] = 5166,
  [SMALL_STATE(136)] = 5198,
  [SMALL_STATE(137)] = 5218,
  [SMALL_STATE(138)] = 5238,
  [SMALL_STATE(139)] = 5258,
  [SMALL_STATE(140)] = 5296,
  [SMALL_STATE(141)] = 5334,
  [SMALL_STATE(142)] = 5372,
  [SMALL_STATE(143)] = 5392,
  [SMALL_STATE(144)] = 5412,
  [SMALL_STATE(145)] = 5432,
  [SMALL_STATE(146)] = 5452,
  [SMALL_STATE(147)] = 5471,
  [SMALL_STATE(148)] = 5506,
  [SMALL_STATE(149)] = 5541,
  [SMALL_STATE(150)] = 5576,
  [SMALL_STATE(151)] = 5611,
  [SMALL_STATE(152)] = 5646,
  [SMALL_STATE(153)] = 5665,
  [SMALL_STATE(154)] = 5684,
  [SMALL_STATE(155)] = 5703,
  [SMALL_STATE(156)] = 5722,
  [SMALL_STATE(157)] = 5741,
  [SMALL_STATE(158)] = 5760,
  [SMALL_STATE(159)] = 5779,
  [SMALL_STATE(160)] = 5798,
  [SMALL_STATE(161)] = 5817,
  [SMALL_STATE(162)] = 5836,
  [SMALL_STATE(163)] = 5855,
  [SMALL_STATE(164)] = 5874,
  [SMALL_STATE(165)] = 5893,
  [SMALL_STATE(166)] = 5912,
  [SMALL_STATE(167)] = 5931,
  [SMALL_STATE(168)] = 5950,
  [SMALL_STATE(169)] = 5969,
  [SMALL_STATE(170)] = 5988,
  [SMALL_STATE(171)] = 6007,
  [SMALL_STATE(172)] = 6026,
  [SMALL_STATE(173)] = 6045,
  [SMALL_STATE(174)] = 6064,
  [SMALL_STATE(175)] = 6083,
  [SMALL_STATE(176)] = 6102,
  [SMALL_STATE(177)] = 6121,
  [SMALL_STATE(178)] = 6140,
  [SMALL_STATE(179)] = 6159,
  [SMALL_STATE(180)] = 6178,
  [SMALL_STATE(181)] = 6197,
  [SMALL_STATE(182)] = 6216,
  [SMALL_STATE(183)] = 6245,
  [SMALL_STATE(184)] = 6264,
  [SMALL_STATE(185)] = 6283,
  [SMALL_STATE(186)] = 6302,
  [SMALL_STATE(187)] = 6321,
  [SMALL_STATE(188)] = 6340,
  [SMALL_STATE(189)] = 6359,
  [SMALL_STATE(190)] = 6378,
  [SMALL_STATE(191)] = 6397,
  [SMALL_STATE(192)] = 6416,
  [SMALL_STATE(193)] = 6435,
  [SMALL_STATE(194)] = 6454,
  [SMALL_STATE(195)] = 6473,
  [SMALL_STATE(196)] = 6492,
  [SMALL_STATE(197)] = 6511,
  [SMALL_STATE(198)] = 6530,
  [SMALL_STATE(199)] = 6549,
  [SMALL_STATE(200)] = 6568,
  [SMALL_STATE(201)] = 6587,
  [SMALL_STATE(202)] = 6616,
  [SMALL_STATE(203)] = 6651,
  [SMALL_STATE(204)] = 6686,
  [SMALL_STATE(205)] = 6721,
  [SMALL_STATE(206)] = 6756,
  [SMALL_STATE(207)] = 6791,
  [SMALL_STATE(208)] = 6826,
  [SMALL_STATE(209)] = 6861,
  [SMALL_STATE(210)] = 6896,
  [SMALL_STATE(211)] = 6931,
  [SMALL_STATE(212)] = 6966,
  [SMALL_STATE(213)] = 7001,
  [SMALL_STATE(214)] = 7036,
  [SMALL_STATE(215)] = 7071,
  [SMALL_STATE(216)] = 7106,
  [SMALL_STATE(217)] = 7141,
  [SMALL_STATE(218)] = 7160,
  [SMALL_STATE(219)] = 7186,
  [SMALL_STATE(220)] = 7212,
  [SMALL_STATE(221)] = 7238,
  [SMALL_STATE(222)] = 7264,
  [SMALL_STATE(223)] = 7290,
  [SMALL_STATE(224)] = 7316,
  [SMALL_STATE(225)] = 7338,
  [SMALL_STATE(226)] = 7361,
  [SMALL_STATE(227)] = 7390,
  [SMALL_STATE(228)] = 7411,
  [SMALL_STATE(229)] = 7429,
  [SMALL_STATE(230)] = 7445,
  [SMALL_STATE(231)] = 7471,
  [SMALL_STATE(232)] = 7497,
  [SMALL_STATE(233)] = 7513,
  [SMALL_STATE(234)] = 7530,
  [SMALL_STATE(235)] = 7547,
  [SMALL_STATE(236)] = 7562,
  [SMALL_STATE(237)] = 7577,
  [SMALL_STATE(238)] = 7600,
  [SMALL_STATE(239)] = 7617,
  [SMALL_STATE(240)] = 7634,
  [SMALL_STATE(241)] = 7651,
  [SMALL_STATE(242)] = 7668,
  [SMALL_STATE(243)] = 7683,
  [SMALL_STATE(244)] = 7701,
  [SMALL_STATE(245)] = 7721,
  [SMALL_STATE(246)] = 7741,
  [SMALL_STATE(247)] = 7761,
  [SMALL_STATE(248)] = 7779,
  [SMALL_STATE(249)] = 7799,
  [SMALL_STATE(250)] = 7819,
  [SMALL_STATE(251)] = 7837,
  [SMALL_STATE(252)] = 7857,
  [SMALL_STATE(253)] = 7877,
  [SMALL_STATE(254)] = 7897,
  [SMALL_STATE(255)] = 7915,
  [SMALL_STATE(256)] = 7933,
  [SMALL_STATE(257)] = 7953,
  [SMALL_STATE(258)] = 7973,
  [SMALL_STATE(259)] = 7993,
  [SMALL_STATE(260)] = 8013,
  [SMALL_STATE(261)] = 8033,
  [SMALL_STATE(262)] = 8047,
  [SMALL_STATE(263)] = 8067,
  [SMALL_STATE(264)] = 8087,
  [SMALL_STATE(265)] = 8107,
  [SMALL_STATE(266)] = 8127,
  [SMALL_STATE(267)] = 8147,
  [SMALL_STATE(268)] = 8167,
  [SMALL_STATE(269)] = 8181,
  [SMALL_STATE(270)] = 8197,
  [SMALL_STATE(271)] = 8211,
  [SMALL_STATE(272)] = 8225,
  [SMALL_STATE(273)] = 8243,
  [SMALL_STATE(274)] = 8257,
  [SMALL_STATE(275)] = 8277,
  [SMALL_STATE(276)] = 8297,
  [SMALL_STATE(277)] = 8317,
  [SMALL_STATE(278)] = 8337,
  [SMALL_STATE(279)] = 8357,
  [SMALL_STATE(280)] = 8377,
  [SMALL_STATE(281)] = 8388,
  [SMALL_STATE(282)] = 8401,
  [SMALL_STATE(283)] = 8416,
  [SMALL_STATE(284)] = 8431,
  [SMALL_STATE(285)] = 8442,
  [SMALL_STATE(286)] = 8461,
  [SMALL_STATE(287)] = 8480,
  [SMALL_STATE(288)] = 8497,
  [SMALL_STATE(289)] = 8510,
  [SMALL_STATE(290)] = 8525,
  [SMALL_STATE(291)] = 8544,
  [SMALL_STATE(292)] = 8555,
  [SMALL_STATE(293)] = 8568,
  [SMALL_STATE(294)] = 8587,
  [SMALL_STATE(295)] = 8600,
  [SMALL_STATE(296)] = 8611,
  [SMALL_STATE(297)] = 8622,
  [SMALL_STATE(298)] = 8635,
  [SMALL_STATE(299)] = 8648,
  [SMALL_STATE(300)] = 8659,
  [SMALL_STATE(301)] = 8670,
  [SMALL_STATE(302)] = 8684,
  [SMALL_STATE(303)] = 8698,
  [SMALL_STATE(304)] = 8712,
  [SMALL_STATE(305)] = 8726,
  [SMALL_STATE(306)] = 8740,
  [SMALL_STATE(307)] = 8752,
  [SMALL_STATE(308)] = 8766,
  [SMALL_STATE(309)] = 8778,
  [SMALL_STATE(310)] = 8792,
  [SMALL_STATE(311)] = 8804,
  [SMALL_STATE(312)] = 8818,
  [SMALL_STATE(313)] = 8832,
  [SMALL_STATE(314)] = 8846,
  [SMALL_STATE(315)] = 8858,
  [SMALL_STATE(316)] = 8872,
  [SMALL_STATE(317)] = 8884,
  [SMALL_STATE(318)] = 8898,
  [SMALL_STATE(319)] = 8912,
  [SMALL_STATE(320)] = 8926,
  [SMALL_STATE(321)] = 8940,
  [SMALL_STATE(322)] = 8954,
  [SMALL_STATE(323)] = 8967,
  [SMALL_STATE(324)] = 8976,
  [SMALL_STATE(325)] = 8989,
  [SMALL_STATE(326)] = 8998,
  [SMALL_STATE(327)] = 9011,
  [SMALL_STATE(328)] = 9024,
  [SMALL_STATE(329)] = 9037,
  [SMALL_STATE(330)] = 9050,
  [SMALL_STATE(331)] = 9061,
  [SMALL_STATE(332)] = 9072,
  [SMALL_STATE(333)] = 9081,
  [SMALL_STATE(334)] = 9090,
  [SMALL_STATE(335)] = 9101,
  [SMALL_STATE(336)] = 9114,
  [SMALL_STATE(337)] = 9127,
  [SMALL_STATE(338)] = 9140,
  [SMALL_STATE(339)] = 9153,
  [SMALL_STATE(340)] = 9166,
  [SMALL_STATE(341)] = 9179,
  [SMALL_STATE(342)] = 9190,
  [SMALL_STATE(343)] = 9199,
  [SMALL_STATE(344)] = 9208,
  [SMALL_STATE(345)] = 9219,
  [SMALL_STATE(346)] = 9232,
  [SMALL_STATE(347)] = 9245,
  [SMALL_STATE(348)] = 9256,
  [SMALL_STATE(349)] = 9267,
  [SMALL_STATE(350)] = 9278,
  [SMALL_STATE(351)] = 9289,
  [SMALL_STATE(352)] = 9302,
  [SMALL_STATE(353)] = 9313,
  [SMALL_STATE(354)] = 9326,
  [SMALL_STATE(355)] = 9337,
  [SMALL_STATE(356)] = 9350,
  [SMALL_STATE(357)] = 9361,
  [SMALL_STATE(358)] = 9372,
  [SMALL_STATE(359)] = 9385,
  [SMALL_STATE(360)] = 9398,
  [SMALL_STATE(361)] = 9407,
  [SMALL_STATE(362)] = 9420,
  [SMALL_STATE(363)] = 9433,
  [SMALL_STATE(364)] = 9446,
  [SMALL_STATE(365)] = 9455,
  [SMALL_STATE(366)] = 9468,
  [SMALL_STATE(367)] = 9481,
  [SMALL_STATE(368)] = 9492,
  [SMALL_STATE(369)] = 9505,
  [SMALL_STATE(370)] = 9518,
  [SMALL_STATE(371)] = 9529,
  [SMALL_STATE(372)] = 9542,
  [SMALL_STATE(373)] = 9555,
  [SMALL_STATE(374)] = 9566,
  [SMALL_STATE(375)] = 9577,
  [SMALL_STATE(376)] = 9588,
  [SMALL_STATE(377)] = 9599,
  [SMALL_STATE(378)] = 9612,
  [SMALL_STATE(379)] = 9625,
  [SMALL_STATE(380)] = 9636,
  [SMALL_STATE(381)] = 9647,
  [SMALL_STATE(382)] = 9660,
  [SMALL_STATE(383)] = 9673,
  [SMALL_STATE(384)] = 9684,
  [SMALL_STATE(385)] = 9695,
  [SMALL_STATE(386)] = 9704,
  [SMALL_STATE(387)] = 9713,
  [SMALL_STATE(388)] = 9726,
  [SMALL_STATE(389)] = 9737,
  [SMALL_STATE(390)] = 9748,
  [SMALL_STATE(391)] = 9759,
  [SMALL_STATE(392)] = 9772,
  [SMALL_STATE(393)] = 9785,
  [SMALL_STATE(394)] = 9798,
  [SMALL_STATE(395)] = 9811,
  [SMALL_STATE(396)] = 9824,
  [SMALL_STATE(397)] = 9837,
  [SMALL_STATE(398)] = 9850,
  [SMALL_STATE(399)] = 9863,
  [SMALL_STATE(400)] = 9874,
  [SMALL_STATE(401)] = 9887,
  [SMALL_STATE(402)] = 9896,
  [SMALL_STATE(403)] = 9909,
  [SMALL_STATE(404)] = 9917,
  [SMALL_STATE(405)] = 9927,
  [SMALL_STATE(406)] = 9937,
  [SMALL_STATE(407)] = 9947,
  [SMALL_STATE(408)] = 9955,
  [SMALL_STATE(409)] = 9965,
  [SMALL_STATE(410)] = 9975,
  [SMALL_STATE(411)] = 9985,
  [SMALL_STATE(412)] = 9993,
  [SMALL_STATE(413)] = 10003,
  [SMALL_STATE(414)] = 10013,
  [SMALL_STATE(415)] = 10023,
  [SMALL_STATE(416)] = 10033,
  [SMALL_STATE(417)] = 10041,
  [SMALL_STATE(418)] = 10051,
  [SMALL_STATE(419)] = 10061,
  [SMALL_STATE(420)] = 10071,
  [SMALL_STATE(421)] = 10079,
  [SMALL_STATE(422)] = 10089,
  [SMALL_STATE(423)] = 10099,
  [SMALL_STATE(424)] = 10107,
  [SMALL_STATE(425)] = 10117,
  [SMALL_STATE(426)] = 10127,
  [SMALL_STATE(427)] = 10137,
  [SMALL_STATE(428)] = 10145,
  [SMALL_STATE(429)] = 10153,
  [SMALL_STATE(430)] = 10163,
  [SMALL_STATE(431)] = 10171,
  [SMALL_STATE(432)] = 10179,
  [SMALL_STATE(433)] = 10189,
  [SMALL_STATE(434)] = 10197,
  [SMALL_STATE(435)] = 10207,
  [SMALL_STATE(436)] = 10217,
  [SMALL_STATE(437)] = 10227,
  [SMALL_STATE(438)] = 10237,
  [SMALL_STATE(439)] = 10244,
  [SMALL_STATE(440)] = 10251,
  [SMALL_STATE(441)] = 10258,
  [SMALL_STATE(442)] = 10265,
  [SMALL_STATE(443)] = 10272,
  [SMALL_STATE(444)] = 10279,
  [SMALL_STATE(445)] = 10286,
  [SMALL_STATE(446)] = 10293,
  [SMALL_STATE(447)] = 10300,
  [SMALL_STATE(448)] = 10307,
  [SMALL_STATE(449)] = 10314,
  [SMALL_STATE(450)] = 10321,
  [SMALL_STATE(451)] = 10328,
  [SMALL_STATE(452)] = 10335,
  [SMALL_STATE(453)] = 10342,
  [SMALL_STATE(454)] = 10349,
  [SMALL_STATE(455)] = 10356,
  [SMALL_STATE(456)] = 10363,
  [SMALL_STATE(457)] = 10370,
  [SMALL_STATE(458)] = 10377,
  [SMALL_STATE(459)] = 10384,
  [SMALL_STATE(460)] = 10391,
  [SMALL_STATE(461)] = 10398,
  [SMALL_STATE(462)] = 10405,
  [SMALL_STATE(463)] = 10412,
  [SMALL_STATE(464)] = 10419,
  [SMALL_STATE(465)] = 10426,
  [SMALL_STATE(466)] = 10433,
  [SMALL_STATE(467)] = 10440,
  [SMALL_STATE(468)] = 10447,
  [SMALL_STATE(469)] = 10454,
  [SMALL_STATE(470)] = 10461,
  [SMALL_STATE(471)] = 10468,
  [SMALL_STATE(472)] = 10475,
  [SMALL_STATE(473)] = 10482,
  [SMALL_STATE(474)] = 10489,
  [SMALL_STATE(475)] = 10496,
  [SMALL_STATE(476)] = 10503,
  [SMALL_STATE(477)] = 10510,
  [SMALL_STATE(478)] = 10517,
  [SMALL_STATE(479)] = 10524,
  [SMALL_STATE(480)] = 10531,
  [SMALL_STATE(481)] = 10538,
  [SMALL_STATE(482)] = 10545,
  [SMALL_STATE(483)] = 10552,
  [SMALL_STATE(484)] = 10559,
  [SMALL_STATE(485)] = 10566,
  [SMALL_STATE(486)] = 10573,
  [SMALL_STATE(487)] = 10580,
  [SMALL_STATE(488)] = 10587,
  [SMALL_STATE(489)] = 10594,
  [SMALL_STATE(490)] = 10601,
  [SMALL_STATE(491)] = 10608,
  [SMALL_STATE(492)] = 10615,
  [SMALL_STATE(493)] = 10622,
  [SMALL_STATE(494)] = 10629,
  [SMALL_STATE(495)] = 10636,
  [SMALL_STATE(496)] = 10643,
  [SMALL_STATE(497)] = 10650,
  [SMALL_STATE(498)] = 10657,
  [SMALL_STATE(499)] = 10664,
  [SMALL_STATE(500)] = 10671,
  [SMALL_STATE(501)] = 10678,
  [SMALL_STATE(502)] = 10685,
  [SMALL_STATE(503)] = 10692,
  [SMALL_STATE(504)] = 10699,
  [SMALL_STATE(505)] = 10706,
  [SMALL_STATE(506)] = 10713,
  [SMALL_STATE(507)] = 10720,
  [SMALL_STATE(508)] = 10727,
  [SMALL_STATE(509)] = 10734,
  [SMALL_STATE(510)] = 10741,
  [SMALL_STATE(511)] = 10748,
  [SMALL_STATE(512)] = 10755,
  [SMALL_STATE(513)] = 10762,
  [SMALL_STATE(514)] = 10769,
  [SMALL_STATE(515)] = 10776,
  [SMALL_STATE(516)] = 10783,
  [SMALL_STATE(517)] = 10790,
  [SMALL_STATE(518)] = 10797,
  [SMALL_STATE(519)] = 10804,
  [SMALL_STATE(520)] = 10811,
  [SMALL_STATE(521)] = 10818,
  [SMALL_STATE(522)] = 10825,
  [SMALL_STATE(523)] = 10832,
  [SMALL_STATE(524)] = 10839,
  [SMALL_STATE(525)] = 10846,
  [SMALL_STATE(526)] = 10853,
  [SMALL_STATE(527)] = 10860,
  [SMALL_STATE(528)] = 10867,
  [SMALL_STATE(529)] = 10874,
  [SMALL_STATE(530)] = 10881,
  [SMALL_STATE(531)] = 10888,
  [SMALL_STATE(532)] = 10895,
  [SMALL_STATE(533)] = 10902,
  [SMALL_STATE(534)] = 10909,
  [SMALL_STATE(535)] = 10916,
  [SMALL_STATE(536)] = 10923,
  [SMALL_STATE(537)] = 10930,
  [SMALL_STATE(538)] = 10937,
  [SMALL_STATE(539)] = 10944,
  [SMALL_STATE(540)] = 10951,
  [SMALL_STATE(541)] = 10958,
  [SMALL_STATE(542)] = 10965,
  [SMALL_STATE(543)] = 10972,
  [SMALL_STATE(544)] = 10979,
  [SMALL_STATE(545)] = 10986,
  [SMALL_STATE(546)] = 10993,
  [SMALL_STATE(547)] = 11000,
  [SMALL_STATE(548)] = 11007,
  [SMALL_STATE(549)] = 11014,
  [SMALL_STATE(550)] = 11021,
  [SMALL_STATE(551)] = 11028,
  [SMALL_STATE(552)] = 11035,
  [SMALL_STATE(553)] = 11042,
  [SMALL_STATE(554)] = 11049,
  [SMALL_STATE(555)] = 11056,
  [SMALL_STATE(556)] = 11063,
  [SMALL_STATE(557)] = 11070,
  [SMALL_STATE(558)] = 11077,
  [SMALL_STATE(559)] = 11084,
  [SMALL_STATE(560)] = 11091,
  [SMALL_STATE(561)] = 11098,
  [SMALL_STATE(562)] = 11105,
  [SMALL_STATE(563)] = 11112,
  [SMALL_STATE(564)] = 11119,
  [SMALL_STATE(565)] = 11126,
  [SMALL_STATE(566)] = 11133,
  [SMALL_STATE(567)] = 11140,
  [SMALL_STATE(568)] = 11147,
  [SMALL_STATE(569)] = 11154,
  [SMALL_STATE(570)] = 11161,
  [SMALL_STATE(571)] = 11168,
  [SMALL_STATE(572)] = 11175,
  [SMALL_STATE(573)] = 11182,
  [SMALL_STATE(574)] = 11189,
  [SMALL_STATE(575)] = 11196,
  [SMALL_STATE(576)] = 11203,
  [SMALL_STATE(577)] = 11210,
  [SMALL_STATE(578)] = 11217,
  [SMALL_STATE(579)] = 11224,
  [SMALL_STATE(580)] = 11231,
  [SMALL_STATE(581)] = 11238,
  [SMALL_STATE(582)] = 11245,
  [SMALL_STATE(583)] = 11252,
  [SMALL_STATE(584)] = 11259,
  [SMALL_STATE(585)] = 11266,
  [SMALL_STATE(586)] = 11273,
  [SMALL_STATE(587)] = 11280,
  [SMALL_STATE(588)] = 11287,
  [SMALL_STATE(589)] = 11294,
  [SMALL_STATE(590)] = 11301,
  [SMALL_STATE(591)] = 11308,
  [SMALL_STATE(592)] = 11315,
  [SMALL_STATE(593)] = 11322,
  [SMALL_STATE(594)] = 11329,
  [SMALL_STATE(595)] = 11336,
  [SMALL_STATE(596)] = 11343,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [29] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [31] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [33] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [36] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(415),
  [39] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(64),
  [42] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [45] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [48] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(408),
  [51] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(454),
  [54] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(345),
  [57] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(421),
  [60] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [63] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [66] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [68] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [70] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [72] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [74] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [76] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [78] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [80] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [82] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [84] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [86] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [88] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [90] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [92] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(252),
  [95] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(434),
  [98] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(62),
  [101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(63),
  [104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(275),
  [107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(435),
  [110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0),
  [115] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(391),
  [118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(492),
  [121] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(569),
  [164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(256),
  [171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(410),
  [174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(59),
  [177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(60),
  [180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(277),
  [183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(563),
  [189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(393),
  [192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(415),
  [198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(64),
  [201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(408),
  [210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(454),
  [213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(345),
  [216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(492),
  [219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0),
  [221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_script_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(279),
  [253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(432),
  [256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(68),
  [259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(67),
  [262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(426),
  [268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [271] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_for_loop_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_name, 1, 0, 0),
  [306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_name, 1, 0, 0),
  [308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_primary_expr, 1, 0, 0),
  [310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_primary_expr, 1, 0, 0),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_multiplicative_expr, 1, 0, 0),
  [316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_multiplicative_expr, 1, 0, 0),
  [318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_array_access, 4, 0, 0),
  [320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array_access, 4, 0, 0),
  [322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_additive_expr, 1, 0, 0),
  [324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_additive_expr, 1, 0, 0),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_additive_expr, 3, 0, 0),
  [330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_additive_expr, 3, 0, 0),
  [332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_primary_expr, 3, 0, 0),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_primary_expr, 3, 0, 0),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_multiplicative_expr, 3, 0, 0),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_multiplicative_expr, 3, 0, 0),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_expression, 1, 0, 0),
  [342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_expression, 1, 0, 0),
  [344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_function_call, 3, 0, 0),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_function_call, 3, 0, 0),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_function_call, 4, 0, 0),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_function_call, 4, 0, 0),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_step_body_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_step_body_repeat1, 2, 0, 0),
  [393] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_step_body_repeat1, 2, 0, 0), SHIFT_REPEAT(274),
  [396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_step_body_repeat1, 2, 0, 0), SHIFT_REPEAT(492),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_step_body, 1, 0, 0),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_block, 2, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_block, 2, 0, 0),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_variable_declaration, 4, 0, 0),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_variable_declaration, 4, 0, 0),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_script, 4, 0, 0),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_script, 4, 0, 0),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_variable_declaration, 3, 0, 0),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_variable_declaration, 3, 0, 0),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_step_block, 3, 0, 0),
  [435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_step_block, 3, 0, 0),
  [437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array_assignment, 4, 0, 0),
  [439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_array_assignment, 4, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_variable_declaration, 5, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_variable_declaration, 5, 0, 0),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_line, 2, 0, 0),
  [447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_line, 2, 0, 0),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_step_block, 2, 0, 0),
  [453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_step_block, 2, 0, 0),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array_assignment, 5, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_array_assignment, 5, 0, 0),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_function_call, 5, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_function_call, 5, 0, 0),
  [465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_variable_declaration, 6, 0, 0),
  [467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_variable_declaration, 6, 0, 0),
  [469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_line, 6, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_geom_line, 6, 0, 0),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_if_block, 6, 0, 0),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_if_block, 6, 0, 0),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_script, 3, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_script, 3, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_if_block, 7, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_if_block, 7, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_end, 1, 0, 0),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_end, 1, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_line, 3, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_line, 3, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_line, 3, 0, 0),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_line, 3, 0, 0),
  [509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_block, 8, 0, 0),
  [511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_geom_block, 8, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_for_loop, 8, 0, 0),
  [515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_for_loop, 8, 0, 0),
  [517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_block, 3, 0, 0),
  [519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_block, 3, 0, 0),
  [521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_if_block, 8, 0, 0),
  [523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_if_block, 8, 0, 0),
  [525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_for_loop, 9, 0, 0),
  [527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_for_loop, 9, 0, 0),
  [529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_if_block, 9, 0, 0),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_if_block, 9, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_assignment, 4, 0, 0),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_assignment, 4, 0, 0),
  [537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_body, 1, 0, 0),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0),
  [541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0), SHIFT_REPEAT(220),
  [544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_input_body_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 1, 0, 0),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 1, 0, 0),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_variable_name, 1, 0, 0), REDUCE(sym_input_key, 1, 0, 0),
  [580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_variable_name, 1, 0, 0), SHIFT(428),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_key, 1, 0, 0),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_content, 2, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_constraint_content_repeat1, 2, 0, 0), SHIFT_REPEAT(418),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constraint_content_repeat1, 2, 0, 0),
  [600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constraint_content_repeat1, 2, 0, 0), SHIFT_REPEAT(227),
  [603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat3, 2, 0, 0),
  [605] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat3, 2, 0, 0), SHIFT_REPEAT(424),
  [608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_key, 1, 0, 0),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_variable_reference, 3, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_variable_reference, 3, 0, 0),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_content, 2, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_content, 1, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0),
  [704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_value_repeat1, 2, 0, 0), SHIFT_REPEAT(182),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 2, 0, 0),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 2, 0, 0),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_simple_line_repeat1, 2, 0, 0),
  [717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_simple_line_repeat1, 2, 0, 0), SHIFT_REPEAT(413),
  [720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_simple_line_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_atom, 1, 0, 0),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_atom, 1, 0, 0),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0), SHIFT_REPEAT(344),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0),
  [744] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0), SHIFT_REPEAT(306),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat1, 2, 0, 0),
  [769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat1, 2, 0, 0), SHIFT_REPEAT(246),
  [772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subblock_repeat2, 2, 0, 0),
  [774] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_subblock_repeat2, 2, 0, 0), SHIFT_REPEAT(443),
  [777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 3, 0, 0),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 3, 0, 0),
  [799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_input_title, 2, 0, 0),
  [809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_input_title, 2, 0, 0),
  [811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_block, 2, 0, 0),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_block, 2, 0, 0),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_block, 3, 0, 0),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_block, 3, 0, 0),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_brace_value, 1, 0, 0),
  [831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_brace_value, 1, 0, 0),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_range, 5, 0, 0),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_range, 5, 0, 0),
  [837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 2, 0, 0),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 2, 0, 0),
  [843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_array, 3, 0, 0),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_array, 3, 0, 0),
  [847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(443),
  [851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_array, 4, 0, 0),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_array, 4, 0, 0),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 3, 0, 0),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 3, 0, 0),
  [861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_brace_content_repeat1, 2, 0, 0),
  [863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 2, 0, 0),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 2, 0, 0),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_value, 1, 0, 0),
  [873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_variable_declaration_repeat1, 2, 0, 0),
  [875] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(422),
  [878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_boolean, 1, 0, 0),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subblock, 4, 2, 1),
  [892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subblock, 4, 2, 1),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_ref, 3, 0, 0),
  [896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_comparison, 3, 0, 0),
  [898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line2, 4, 0, 2),
  [900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line2, 4, 0, 2),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_argument_list, 2, 0, 0),
  [924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xyz_line, 5, 0, 0),
  [926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xyz_line, 5, 0, 0),
  [928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array, 2, 0, 0),
  [930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_condition, 3, 0, 0),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_def, 4, 0, 0),
  [938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_def, 4, 0, 0),
  [940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line3, 6, 0, 3),
  [942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line3, 6, 0, 3),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_int_line, 8, 0, 4),
  [948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_int_line, 8, 0, 4),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line4, 8, 0, 5),
  [954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line4, 8, 0, 5),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [960] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_kv_pair, 4, 0, 0),
  [962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kv_pair, 4, 0, 0),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subblock, 3, 2, 1),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subblock, 3, 2, 1),
  [972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_content, 1, 0, 0),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_content, 1, 0, 0),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(205),
  [981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_argument_list_repeat1, 2, 0, 0),
  [983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array, 3, 0, 0),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_condition, 1, 0, 0),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [1005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_argument_list, 1, 0, 0),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_zmat_line1, 2, 0, 0),
  [1013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_zmat_line1, 2, 0, 0),
  [1015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arg, 1, 0, 0),
  [1017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arg, 1, 0, 0),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_coord_value, 1, 0, 0),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_array_repeat1, 2, 0, 0),
  [1037] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_array_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_array, 4, 0, 0),
  [1048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_array_repeat1, 2, 0, 0), SHIFT_REPEAT(218),
  [1051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_array_repeat1, 2, 0, 0),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [1059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_coord_value, 1, 0, 0),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [1063] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_ref, 3, 0, 0),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [1075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [1079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_geom_line_types, 1, 0, 0),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [1087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1253] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_content, 3, 0, 0),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_assignment_value, 1, 0, 0),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_orca(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "orca",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
